@@ -1,11 +1,4 @@
 <!DOCTYPE TS><TS>
-<context>
-    <name></name>
-    <message>
-        <source>UNKNOWN CUT</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>QObject</name>
     <message>
@@ -16,6 +9,318 @@
         <source>Couldn&apos;t open mySQL connection!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Sequentially</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Randomly</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Feature</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Theme Open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Theme Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Theme Open/Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Background</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Commercial/Jingle/Promo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UNKNOWN CUT</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Segue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Panel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Macro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PLAY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SEGUE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UNKNOWN</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Marker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open Bracket</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close Bracket</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ChainTo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Link</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Traffic</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLogManager</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Macro Event</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch Event</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Playout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Download</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Short Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Low Level</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>High Level</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Downloading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Internal Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Interrupted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Playing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Waiting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Device Busy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No Such Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown Audio Format</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Text Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ASCAP/BMI Electronic Music Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Technical Playout Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SoundExchange Statutory License Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RadioTraffic.com Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>VisualTraffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CounterPoint Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music1 Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Report complete!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Report canceled!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open report file!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>invalid SQL or failed DB connection:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music Summary</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>WideOrbit Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown Position</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Center</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Center</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NPR/DS SoundExchange Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music Playout</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -234,45 +539,6 @@ Color</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>RDCart</name>
-    <message>
-        <source>Sequentially</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Randomly</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unknown</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Feature</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Theme Open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Theme Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Theme Open/Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Background</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Commercial/Jingle/Promo</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>RDCartDialog</name>
     <message>
@@ -364,6 +630,43 @@ Color</source>
         <source>Matches</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Load From
+&amp;File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create temporary cart for import!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to get temporary cart number for import!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Imported from</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDCutDialog</name>
@@ -444,6 +747,10 @@ Cart</source>
         <source>Matches</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDDateDialog</name>
@@ -697,6 +1004,20 @@ Marker</source>
         <source>Edit Audio</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Marker Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Less than half of the audio is playable with these marker settings.
+Are you sure you want to save?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>More than half of the audio will be faded with these marker settings.
+Are you sure you want to save?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDEditPanelName</name>
@@ -1206,97 +1527,6 @@ Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>RDLogLine</name>
-    <message>
-        <source>Unknown</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Manual</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Segue</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Time</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Panel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Macro</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PLAY</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SEGUE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>STOP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>UNKNOWN</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Marker</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open Bracket</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Close Bracket</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>ChainTo</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Track</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Link</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Traffic</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Music</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RDLogManager</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Tracker</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>RDPasswd</name>
     <message>
@@ -1333,156 +1563,6 @@ please try again!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>RDRecording</name>
-    <message>
-        <source>Recording</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Macro Event</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Switch Event</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Playout</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Download</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Upload</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Ok</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Short Length</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Low Level</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>High Level</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Downloading</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Uploading</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Server Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Internal Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Interrupted</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Playing</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Waiting</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Device Busy</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>No Such Cart/Cut</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unknown Audio Format</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>RDReport</name>
-    <message>
-        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Text Log</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>ASCAP/BMI Electronic Music Report</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Technical Playout Report</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SoundExchange Statutory License Report</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unknown</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Other</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>AM</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>FM</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Report complete!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Report canceled!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to open report file!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RadioTraffic.com Traffic Reconciliation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>VisualTraffic Reconciliation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CounterPoint Traffic Reconciliation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Music1 Reconciliation</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>RDSoundPanel</name>
     <message>
