@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdaudioconvert.cpp,v 1.9 2011/01/10 18:48:20 cvs Exp $
+//      $Id: rdaudioconvert.cpp,v 1.14.2.2 2012/12/13 22:33:44 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,6 +27,7 @@
 #include <unistd.h>
 #include <math.h>
 #include <dlfcn.h>
+#include <errno.h>
 
 #include <sndfile.h>
 #include <samplerate.h>
@@ -255,6 +256,14 @@ QString RDAudioConvert::errorText(RDAudioConvert::ErrorCode err)
   case RDAudioConvert::ErrorInvalidSpeed:
     ret=tr("Invalid speed ratio");
     break;
+
+  case RDAudioConvert::ErrorFormatError:
+    ret=tr("Source format error");
+    break;
+
+  case RDAudioConvert::ErrorNoSpace:
+    ret=tr("No space left on device");
+    break;
   }
   return ret;
 }
@@ -568,13 +577,16 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Mpeg(const QString &dstfile,
   }
   while((n=wave->readWave(buffer+left_over,fsize))>0) {
     if((buffer[left_over]==0xff)&&(buffer[2+left_over]&0x02)!=0) {
-      n+=wave->readWave(buffer+left_over+n,1);  // Padding slot
+       n+=wave->readWave(buffer+left_over+n,1);  // Padding slot
     }
     mad_stream_buffer(&mad_stream,buffer,n+left_over);
-    if(mad_stream.error==MAD_ERROR_LOSTSYNC) {  // FIXME: try to recover!!!
-      break;
+    //printf("mad err: %d\n",mad_stream.error);
+   if(mad_stream.error==MAD_ERROR_LOSTSYNC) {  // FIXME: try to recover!!!
+     //    return RDAudioConvert::ErrorFormatError;
+     //break;
     }
     while(mad_frame_decode(&mad_frame,&mad_stream)==0) {
+      //printf("decoding...\n");
       mad_synth_frame(&mad_synth,&mad_frame);
       for(int i=0;i<mad_synth.pcm.length;i++) {
 	for(int j=0;j<mad_synth.pcm.channels;j++) {
@@ -709,7 +721,6 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
   int err;
   sf_count_t n;
   float ratio=1.0;
-  unsigned max_chans=2;
 
   //
   // Open Files
@@ -719,6 +730,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
     return RDAudioConvert::ErrorInternal;
   }
   sf_command(src_sf,SFC_SET_NORM_FLOAT,NULL,SF_FALSE);
+  sf_command(dst_sf,SFC_SET_CLIPPING,NULL,SF_TRUE);
   memset(&dst_info,0,sizeof(dst_info));
   dst_info.format=SF_FORMAT_WAV|SF_FORMAT_PCM_32;
   dst_info.channels=conv_settings->channels();
@@ -861,7 +873,19 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
     //
     // Write Output
     //
-    sf_writef_float(dst_sf,pcm[2],n);
+    if(sf_writef_float(dst_sf,pcm[2],n)!=n) {
+      for(unsigned i=0;i<3;i++) {
+	if(free_pcm[i]) {
+	  delete pcm[i];
+	}
+      }
+      if(src_state!=NULL) {
+	src_delete(src_state);
+      }
+      sf_close(src_sf);
+      sf_close(dst_sf);
+      return RDAudioConvert::ErrorNoSpace;
+    }
   }
 
   //
@@ -871,7 +895,19 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
     st_conv->flush();
     while((n=st_conv->
 	   receiveSamples(pcm[2],STAGE2_BUFFER_SIZE/dst_info.channels))>0) {
-      sf_writef_float(dst_sf,pcm[2],n);
+      if(sf_writef_float(dst_sf,pcm[2],n)!=n) {
+	for(unsigned i=0;i<3;i++) {
+	  if(free_pcm[i]) {
+	    delete pcm[i];
+	  }
+	}
+	if(src_state!=NULL) {
+	  src_delete(src_state);
+	}
+	sf_close(src_sf);
+	sf_close(dst_sf);
+	return RDAudioConvert::ErrorNoSpace;
+      }
     }
     delete st_conv;
   }
@@ -885,7 +921,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
     }
   }
   if(src_state!=NULL) {
-    delete src_state;
+    src_delete(src_state);
   }
   sf_close(src_sf);
   sf_close(dst_sf);
@@ -948,7 +984,6 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Flac(SNDFILE *src_sf,
 						     const QString &dstfile)
 {
 #ifdef HAVE_FLAC
-  int dst_fd=-1;
   sf_count_t n;
   int32_t *pcm;
 
@@ -1036,7 +1071,6 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Vorbis(SNDFILE *src_sf,
   ogg_packet header;
   ogg_packet comment;
   ogg_packet codebook;
-  ogg_packet ogg_eos_packet;
   ogg_packet ogg_packet;
   vorbis_info vorbis_info;
   vorbis_comment vorbis_comment;
@@ -1092,7 +1126,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Vorbis(SNDFILE *src_sf,
   while((n=sf_readf_float(src_sf,pcm,2048))>0) {
     vorbis=vorbis_analysis_buffer(&vorbis_dsp,n);
     for(unsigned i=0;i<n;i++) {
-      for(unsigned j=0;j<src_sf_info->channels;j++) {
+      for(int j=0;j<src_sf_info->channels;j++) {
 	vorbis[j][i]=pcm[src_sf_info->channels*i+j];
       }
     }
@@ -1101,16 +1135,46 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Vorbis(SNDFILE *src_sf,
       vorbis_analysis(&vorbis_block,&ogg_packet);
       ogg_stream_packetin(&ogg_stream,&ogg_packet);
       while(ogg_stream_pageout(&ogg_stream,&ogg_page)!=0) {
-	write(dst_fd,ogg_page.header,ogg_page.header_len);
-	write(dst_fd,ogg_page.body,ogg_page.body_len);
+	if(write(dst_fd,ogg_page.header,ogg_page.header_len)!=
+	   ogg_page.header_len) {
+	  ::close(dst_fd);
+	  delete pcm;
+	  ogg_stream_clear(&ogg_stream);
+	  vorbis_comment_clear(&vorbis_comment);
+	  vorbis_info_clear(&vorbis_info);
+	  return RDAudioConvert::ErrorNoSpace; 
+	}
+	if(write(dst_fd,ogg_page.body,ogg_page.body_len)!=
+	   ogg_page.body_len) {
+	  ::close(dst_fd);
+	  delete pcm;
+	  ogg_stream_clear(&ogg_stream);
+	  vorbis_comment_clear(&vorbis_comment);
+	  vorbis_info_clear(&vorbis_info);
+	  return RDAudioConvert::ErrorNoSpace; 
+	}
       }
     }
     while(ogg_stream_flush(&ogg_stream,&ogg_page)!=0) {
-      write(dst_fd,ogg_page.header,ogg_page.header_len);
-      write(dst_fd,ogg_page.body,ogg_page.body_len);
+      if(write(dst_fd,ogg_page.header,ogg_page.header_len)!=
+	 ogg_page.header_len) {
+	  ::close(dst_fd);
+	  delete pcm;
+	  ogg_stream_clear(&ogg_stream);
+	  vorbis_comment_clear(&vorbis_comment);
+	  vorbis_info_clear(&vorbis_info);
+	  return RDAudioConvert::ErrorNoSpace; 
+	}
+      }
+    if(write(dst_fd,ogg_page.body,ogg_page.body_len)!=
+       ogg_page.body_len) {
+      ::close(dst_fd);
+      delete pcm;
+      ogg_stream_clear(&ogg_stream);
+      vorbis_comment_clear(&vorbis_comment);
+      vorbis_info_clear(&vorbis_info);
+      return RDAudioConvert::ErrorNoSpace; 
     }
-
-
   }
   vorbis=vorbis_analysis_buffer(&vorbis_dsp,0);
   vorbis_analysis_wrote(&vorbis_dsp,0);
@@ -1118,13 +1182,45 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Vorbis(SNDFILE *src_sf,
     vorbis_analysis(&vorbis_block,&ogg_packet);
     ogg_stream_packetin(&ogg_stream,&ogg_packet);
     while(ogg_stream_pageout(&ogg_stream,&ogg_page)!=0) {
-      write(dst_fd,ogg_page.header,ogg_page.header_len);
-      write(dst_fd,ogg_page.body,ogg_page.body_len);
+      if(write(dst_fd,ogg_page.header,ogg_page.header_len)!=
+	 ogg_page.header_len) {
+	::close(dst_fd);
+	delete pcm;
+	ogg_stream_clear(&ogg_stream);
+	vorbis_comment_clear(&vorbis_comment);
+	vorbis_info_clear(&vorbis_info);
+	return RDAudioConvert::ErrorNoSpace; 
+      }
+      if(write(dst_fd,ogg_page.body,ogg_page.body_len)!=
+	 ogg_page.body_len) {
+	::close(dst_fd);
+	delete pcm;
+	ogg_stream_clear(&ogg_stream);
+	vorbis_comment_clear(&vorbis_comment);
+	vorbis_info_clear(&vorbis_info);
+	return RDAudioConvert::ErrorNoSpace; 
+      }
     }
   }
   while(ogg_stream_flush(&ogg_stream,&ogg_page)!=0) {
-    write(dst_fd,ogg_page.header,ogg_page.header_len);
-    write(dst_fd,ogg_page.body,ogg_page.body_len);
+    if(write(dst_fd,ogg_page.header,ogg_page.header_len)!=
+       ogg_page.header_len) {
+      ::close(dst_fd);
+      delete pcm;
+      ogg_stream_clear(&ogg_stream);
+      vorbis_comment_clear(&vorbis_comment);
+      vorbis_info_clear(&vorbis_info);
+      return RDAudioConvert::ErrorNoSpace; 
+    }
+    if(write(dst_fd,ogg_page.body,ogg_page.body_len)!=
+       ogg_page.body_len) {
+      ::close(dst_fd);
+      delete pcm;
+      ogg_stream_clear(&ogg_stream);
+      vorbis_comment_clear(&vorbis_comment);
+      vorbis_info_clear(&vorbis_info);
+      return RDAudioConvert::ErrorNoSpace; 
+    }
   }
 
   //
@@ -1201,6 +1297,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer3(SNDFILE *src_sf,
   lame_set_in_samplerate(lameopts,src_sf_info->samplerate);
   lame_set_out_samplerate(lameopts,src_sf_info->samplerate);
   lame_set_brate(lameopts,conv_settings->bitRate()/1000);
+  lame_set_bWriteVbrTag(lameopts,0);
   if(lame_init_params(lameopts)!=0) {
     lame_close(lameopts);
     ::close(dst_fd);
@@ -1213,19 +1310,31 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer3(SNDFILE *src_sf,
   if(src_sf_info->channels==2) {
     while((n=sf_readf_short(src_sf,pcm,1152))>0) {
       if((s=lame_encode_buffer_interleaved(lameopts,pcm,n,mpeg,2048))>=0) {
-	write(dst_fd,mpeg,s);
+	if(write(dst_fd,mpeg,s)!=s) {
+	  lame_close(lameopts);
+	  ::close(dst_fd);
+	  return RDAudioConvert::ErrorNoSpace;
+	}
       }
     }
   }
   else {
     while((n=sf_readf_short(src_sf,pcm,1152))>0) {
       if((s=lame_encode_buffer(lameopts,pcm,NULL,n,mpeg,2048))>=0) {
-	write(dst_fd,mpeg,s);
+	if(write(dst_fd,mpeg,s)!=s) {
+	  lame_close(lameopts);
+	  ::close(dst_fd);
+	  return RDAudioConvert::ErrorNoSpace;
+	}
       }
     }
   }
   if((s=lame_encode_flush(lameopts,mpeg,2048))>=0) {
-      write(dst_fd,mpeg,s);
+    if(write(dst_fd,mpeg,s)!=s) {
+      lame_close(lameopts);
+      ::close(dst_fd);
+      return RDAudioConvert::ErrorNoSpace;
+    }
   }
 
   //
@@ -1338,14 +1447,22 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer2Wav(SNDFILE *src_sf,
   while((n=sf_readf_float(src_sf,pcm,1152))>0) {
     if((s=twolame_encode_buffer_float32_interleaved(lameopts,
 						    pcm,n,mpeg,2048))>=0) {
-      wave->writeWave(mpeg,s);
+      if(wave->writeWave(mpeg,s)!=s) {
+	twolame_close(&lameopts);
+	wave->closeWave(src_sf_info->frames);
+	return RDAudioConvert::ErrorNoSpace;
+      }
     }
     else {
       fprintf(stderr,"TwoLAME encode error\n");
     }
   }
   if((s=twolame_encode_flush(lameopts,mpeg,2048))>=0) {
-    wave->writeWave(mpeg,s);
+    if(wave->writeWave(mpeg,s)!=s) {
+      twolame_close(&lameopts);
+      wave->closeWave(src_sf_info->frames);
+      return RDAudioConvert::ErrorNoSpace;
+    }
   }
   else {
     fprintf(stderr,"TwoLAME encode error\n");
@@ -1368,7 +1485,6 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer2(SNDFILE *src_sf,
 						       const QString &dstfile)
 {
 #ifdef HAVE_TWOLAME
-  short *sf_buffer=NULL;
   sf_count_t n;
   ssize_t s;
   int dst_fd=-1;
@@ -1433,14 +1549,22 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer2(SNDFILE *src_sf,
   while((n=sf_readf_float(src_sf,pcm,1152))>0) {
     if((s=twolame_encode_buffer_float32_interleaved(lameopts,
 						    pcm,n,mpeg,2048))>=0) {
-      write(dst_fd,mpeg,s);
+      if(write(dst_fd,mpeg,s)!=s) {
+	twolame_close(&lameopts);
+	::close(dst_fd);
+	return RDAudioConvert::ErrorNoSpace;
+      }
     }
     else {
       fprintf(stderr,"TwoLAME encode error\n");
     }
   }
   if((s=twolame_encode_flush(lameopts,mpeg,2048))>=0) {
-      write(dst_fd,mpeg,s);
+    if(write(dst_fd,mpeg,s)!=s) {
+      twolame_close(&lameopts);
+      ::close(dst_fd);
+      return RDAudioConvert::ErrorNoSpace;
+    }
   }
   else {
     fprintf(stderr,"TwoLAME encode error\n");
@@ -1492,7 +1616,14 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Pcm16(SNDFILE *src_sf,
     return RDAudioConvert::ErrorNoDestination;
   }
   while((n=sf_readf_short(src_sf,sf_buffer,2048))>0) {
-    wave->writeWave(sf_buffer,n*sizeof(short)*src_sf_info->channels);
+    if((unsigned)wave->
+       writeWave(sf_buffer,n*sizeof(short)*src_sf_info->channels)!=
+       (n*sizeof(short)*src_sf_info->channels)) {
+      delete sf_buffer;
+      wave->closeWave();
+      delete wave;
+      return RDAudioConvert::ErrorNoSpace;
+    }
   }
   delete sf_buffer;
   wave->closeWave();
@@ -1663,6 +1794,8 @@ bool RDAudioConvert::LoadLame()
   *(void **)(&lame_encode_buffer)=
     dlsym(conv_lame_handle,"lame_encode_buffer");
   *(void **)(&lame_encode_flush)=dlsym(conv_lame_handle,"lame_encode_flush");
+  *(void **)(&lame_set_bWriteVbrTag)=
+    dlsym(conv_lame_handle,"lame_set_bWriteVbrTag");
   return true;
 #else
   return false;
