@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdconfig.cpp,v 1.19 2008/04/09 16:58:38 fredg Exp $
+//      $Id: rdconfig.cpp,v 1.24.6.4 2012/12/13 22:33:44 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,6 +29,7 @@
 
 #include <qmessagebox.h>
 #include <qsettings.h>
+#include <qstringlist.h>
 
 #include <rdprofile.h>
 #include <rdconfig.h>
@@ -85,12 +86,31 @@ QString RDConfig::audioFileName (QString cutname)
     audioExtension();
 };
 
+QString RDConfig::label() const
+{
+  return conf_label;
+}
+
+QString RDConfig::audioStoreMountSource() const
+{
+  return conf_audio_store_mount_source;
+}
+
+QString RDConfig::audioStoreMountType() const
+{
+  return conf_audio_store_mount_type;
+}
+
+QString RDConfig::audioStoreMountOptions() const
+{
+  return conf_audio_store_mount_options;
+}
+
 QString RDConfig::mysqlHostname() const
 {
   return conf_mysql_hostname;
 }
 
-
 QString RDConfig::mysqlUsername() const
 {
   return conf_mysql_username;
@@ -145,6 +165,12 @@ QString RDConfig::logPattern() const
 }
 
 
+bool RDConfig::logXloadDebugData() const
+{
+  return conf_log_xload_debug_data;
+}
+
+
 void RDConfig::log(const QString &module,LogPriority prio,const QString &msg)
 {
 #ifndef WIN32
@@ -260,12 +286,6 @@ bool RDConfig::useStreamMeters() const
 }
 
 
-unsigned RDConfig::sampleRate() const
-{
-  return conf_sample_rate;
-}
-
-
 unsigned RDConfig::channels() const
 {
   return conf_channels;
@@ -346,6 +366,7 @@ QString RDConfig::destination(unsigned n)
 void RDConfig::load()
 {
   char sname[256];
+  QString client;
   QString facility;
 #ifndef WIN32
   struct passwd *user;
@@ -358,6 +379,8 @@ void RDConfig::load()
   strcpy(sname,"windows");
 #else
   gethostname(sname,255);
+  QStringList list=list.split(".",sname);  // Strip domain name parts
+  strncpy(sname,list[0],256);
 #endif
   conf_station_name=
     profile->stringValue("Identity","StationName",sname);
@@ -366,6 +389,16 @@ void RDConfig::load()
     profile->stringValue("Identity","AudioOwner",RD_DEFAULT_AUDIO_OWNER);
   conf_audio_group=
     profile->stringValue("Identity","AudioGroup",RD_DEFAULT_AUDIO_GROUP);
+  conf_label=profile->stringValue("Identity","Label",RD_DEFAULT_LABEL);
+
+  conf_audio_store_mount_source=
+    profile->stringValue("AudioStore","MountSource");
+  conf_audio_store_mount_type=
+    profile->stringValue("AudioStore","MountType");
+  conf_audio_store_mount_options=
+    profile->stringValue("AudioStore","MountOptions",
+			 RD_DEFAULT_AUDIO_STORE_MOUNT_OPTIONS);
+
   conf_audio_root=
     profile->stringValue("Cae","AudioRoot",RD_AUDIO_ROOT);
   conf_audio_extension=
@@ -393,6 +426,8 @@ void RDConfig::load()
   conf_log_directory=profile->stringValue("Logs","LogDirectory","");
   conf_log_pattern=profile->stringValue("Logs","LogPattern",
 					DEFAULT_LOG_PATTERN);
+  conf_log_xload_debug_data=profile->
+    boolValue("Logs","LogXloadDebugData",false);
   conf_log_core_dump_directory=
     profile->stringValue("Logs","CoreDumpDirectory",
 			 DEFAULT_LOG_CORE_DUMP_DIRECTORY);
@@ -405,8 +440,6 @@ void RDConfig::load()
   conf_airplay_logname=profile->stringValue("RDAirPlay","Logfile","");
   conf_catchd_logname=profile->stringValue("RDCatchd","Logfile","");
   conf_use_stream_meters=profile->boolValue("Hacks","UseStreamMeters",false);
-  conf_sample_rate=profile->intValue("Format","SampleRate",
-				     RD_DEFAULT_SAMPLE_RATE);
   conf_channels=profile->intValue("Format","Channels",RD_DEFAULT_CHANNELS);
 #ifndef WIN32
   if((user=getpwnam(profile->stringValue("Identity","AudioOwner")))!=NULL) {
@@ -457,6 +490,7 @@ void RDConfig::clear()
   conf_log_directory="";
   conf_log_core_dump_directory=DEFAULT_LOG_CORE_DUMP_DIRECTORY;
   conf_log_pattern=DEFAULT_LOG_PATTERN;
+  conf_log_xload_debug_data=false;
   conf_alsa_period_quantity=RD_ALSA_DEFAULT_PERIOD_QUANTITY;
   conf_alsa_period_size=RD_ALSA_DEFAULT_PERIOD_SIZE;
   conf_station_name="";
@@ -465,13 +499,16 @@ void RDConfig::clear()
   conf_audio_group="";
   conf_audio_root=RD_AUDIO_ROOT;
   conf_audio_extension=RD_AUDIO_EXTENSION;
+  conf_label=RD_DEFAULT_LABEL;
+  conf_audio_store_mount_source="";
+  conf_audio_store_mount_type="";
+  conf_audio_store_mount_options=RD_DEFAULT_AUDIO_STORE_MOUNT_OPTIONS;
   conf_ripcd_logname="";
   conf_airplay_logname="";
   conf_catchd_logname="";
   conf_jack_ports[0].clear();
   conf_jack_ports[1].clear();
   conf_use_stream_meters=false;
-  conf_sample_rate=RD_DEFAULT_SAMPLE_RATE;
   conf_channels=RD_DEFAULT_CHANNELS;
 #ifndef WIN32
   conf_uid=65535;
