@@ -2,9 +2,9 @@
 //
 // Audio File Importation Dialog for Rivendell.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2004,2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport_audio.cpp,v 1.22.2.2 2010/02/09 21:43:53 cvs Exp $
+//      $Id: rdimport_audio.cpp,v 1.27 2011/12/23 22:04:11 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -47,7 +47,8 @@
 RDImportAudio::RDImportAudio(QString cutname,QString *path,
 			     RDSettings *settings,bool *import_metadata,
 			     RDWaveData *wavedata,RDCut *clipboard,
-			     RDStation *station,bool *running,RDConfig *config,
+			     RDStation *station,RDUser *user,
+			     bool *running,RDConfig *config,
 			     QWidget *parent,const char *name) 
   : QDialog(parent,name)
 {
@@ -59,9 +60,12 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_import_metadata=import_metadata;
   import_wavedata=wavedata;
   import_clipboard=clipboard;
-  import_station=station;
   import_running=running;
+  import_station=station;
+  import_user=user;
   import_file_filter=RD_AUDIO_FILE_FILTER;
+  import_import_conv=NULL;
+  import_export_conv=NULL;
 
   setCaption(tr("Import/Export Audio File"));
 
@@ -208,7 +212,6 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_out_metadata_box->setGeometry(95,161,sizeHint().width()-210,15);
   import_out_metadata_box->setChecked(*import_import_metadata);
   import_out_metadata_box->setFont(label_font);
-  import_out_metadata_box->hide();
 
   //
   // Output Format
@@ -235,15 +238,9 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   //
   // Progress Bar
   //
-  import_bar=new QProgressBar(this,"import_bar");
+  import_bar=new RDBusyBar(this,"import_bar");
   import_bar->setGeometry(10,230,sizeHint().width()-20,20);
 
-  //
-  // Progress Bar Timer
-  //
-  import_bar_timer=new QTimer(this,"import_bar_timer");
-  connect(import_bar_timer,SIGNAL(timeout()),this,SLOT(barTimerData()));
-
   //
   // Normalize Check Box
   //
@@ -429,17 +426,6 @@ void RDImportAudio::autotrimCheckData(bool state)
 }
 
 
-void RDImportAudio::barTimerData()
-{
-  if(import_mode_group->selectedId()==0) {
-    ImportProgress();
-  }
-  else {
-    ExportProgress();
-  }
-}
-
-
 void RDImportAudio::selectInputFileData()
 {
   QString filename;
@@ -501,6 +487,14 @@ void RDImportAudio::selectOutputFormatData()
 
 void RDImportAudio::importData()
 {
+  if(import_import_conv!=NULL) {
+    import_import_conv->abort();
+    return;
+  }
+  if(import_export_conv!=NULL) {
+    import_export_conv->abort();
+    return;
+  }
   if(import_mode_group->selectedId()==0) {
     Import();
   }
@@ -534,265 +528,89 @@ void RDImportAudio::paintEvent(QPaintEvent *e)
 void RDImportAudio::closeEvent(QCloseEvent *e)
 {
   if(!(*import_running)) {
-//    cancelData();
+    cancelData();
   }
 }
 
 
 void RDImportAudio::Import()
 {
-  int format_in=0;
+  RDSettings settings;
+  RDAudioImport::ErrorCode conv_err;
+  RDAudioConvert::ErrorCode audio_conv_err;
 
   if(*import_running) {
     return;
   }
 
+  import_import_button->setText(tr("Abort"));
   if(!QFile::exists(import_in_filename_edit->text())) {
     QMessageBox::warning(this,tr("Import Audio File"),
 			 tr("File does not exist!"));
     return;
   }
-  RDWaveFile *wave=new RDWaveFile(import_in_filename_edit->text());
-  if(!wave->openWave(import_wavedata)) {
-    QMessageBox::warning(this,tr("Import Audio File"),tr("Cannot open file!"));
-    delete wave;
-    return;
-  }
-  if(wave->type()==RDWaveFile::Unknown) {
-    QMessageBox::warning(this,tr("Import Audio File"),
-			 tr("Unsupported file type!"));
-    wave->closeWave();
-    delete wave;
-    return;
-  }
-  int samplerate=wave->getSamplesPerSec();
-  switch(wave->getFormatTag()) {
-      case WAVE_FORMAT_PCM:
-	format_in=0;
-	import_temp_length=wave->getSampleLength()*
-	  wave->getChannels()*(wave->getBitsPerSample()/8);
-	break;
-
-      case WAVE_FORMAT_MPEG:
-	format_in=wave->getHeadLayer();
-	import_temp_length=wave->getSampleLength()*wave->getChannels()*2;
-	break;
-
-      case WAVE_FORMAT_FLAC:
-	format_in=0;
-	import_temp_length=wave->getSampleLength()*wave->getChannels()*2;
-	break;
-  }
-  delete wave;
-
-  import_import_aborted=false;
-  import_dest_filename=RDCut::pathName(import_cutname);
-  if(QFile::exists(import_dest_filename)) {
-    switch(QMessageBox::
-       warning(this,tr("Audio Exists"),
-	       tr("This will overwrite the existing recording.\nDo you want to proceed?"),
-	       QMessageBox::Yes,QMessageBox::No)) {
-	case QMessageBox::No:
-	case QMessageBox::NoButton:
-	  return;
-	  break;
-
-	default:
-	  break;
-    }
-    if(import_clipboard!=NULL) {
-      if(import_cutname==import_clipboard->cutName()) {
-	switch(QMessageBox::warning(this,tr("Empty Clipboard"),
-				    tr("Importing this cut will also empty the clipboard.\nDo you still want to proceed?"),
-				    QMessageBox::Yes,
-				    QMessageBox::No)) {
-	    case QMessageBox::No:
-	    case QMessageBox::NoButton:
-	      return;
-
-	    default:
-	      break;
-	}
-	delete import_clipboard;
-	import_clipboard=NULL;
-      }
-    }
-  }
-
-  int lib_fmt=0;
-  switch(import_default_settings->format()) {
-      case RDSettings::Pcm16:  // PCM16
-	import_finished_length=
-	  (int)(((double)import_temp_length/2.0)*
-		(double)(import_channels_box->currentItem()+1.0)*
-		(double)import_default_settings->sampleRate()/44100.0);
-	lib_fmt=0;
-	break;
-
-      case RDSettings::MpegL2:  // MPEG-1 Layer 2
-	import_finished_length=
-	  (int)((double)import_temp_length*
-		(double)(import_channels_box->currentItem()+1)*
-		(double)import_default_settings->bitRate()/1411200.0);
-	lib_fmt=1;
-	break;
-
-      case RDSettings::MpegL1:
-      case RDSettings::MpegL3:
-      case RDSettings::Flac:
-      case RDSettings::OggVorbis:
-	break;
-  }
 
   //
-  // Generate Temporary Filenames
+  // Import
   //
-  QString tempname=tempnam(NULL,IMPORT_TEMP_BASENAME);
-  import_tempwav_name=tempname+".wav";
-  import_tempdat_name=tempname+".dat";
-
-  QString cmd;
-  float normal=0.0;
-  RDLibraryConf *rdlibrary=new RDLibraryConf(import_station->name(),0);
+  StartBar();
+  RDCut *cut=new RDCut(import_cutname);
+  import_import_conv=new RDAudioImport(import_station,this);
+  import_import_conv->setCartNumber(cut->cartNumber());
+  import_import_conv->setCutNumber(cut->cutNumber());
+  import_import_conv->setSourceFile(import_in_filename_edit->text());
+  settings.setChannels(import_channels_box->currentItem()+1);
   if(import_normalize_box->isChecked()) {
-    normal=pow(10.0,(double)(import_normalize_spin->value())/20.0);
-    import_multipass=true;
-    cmd=QString().
-      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s %s %s %d",
-	      normal,
-	      format_in,
-	      samplerate,
-	      (const char *)RDEscapeString(import_in_filename_edit->text()).utf8(),  
-	      lib_fmt,
-	      import_channels_box->currentItem()+1,
-	      import_default_settings->sampleRate(),
-	      (import_channels_box->
-	       currentItem()+1)*import_default_settings->bitRate()/1000,
-	      RDCut::pathName(import_cutname).ascii(),  
-	      (const char *)import_tempdat_name,
-	      (const char *)import_tempwav_name,
-	      rdlibrary->srcConverter());
+    settings.setNormalizationLevel(import_normalize_spin->value());
   }
-  else {
-    import_multipass=false;
-    cmd=QString().
-      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s %s %s %d",
-	      format_in,
-	      samplerate,
-	      (const char *)RDEscapeString(import_in_filename_edit->text()).utf8(),
-	      lib_fmt,
-	      import_channels_box->currentItem()+1,
-	      import_default_settings->sampleRate(),
-	      (import_channels_box->
-	       currentItem()+1)*import_default_settings->bitRate()/1000,
-	      RDCut::pathName(import_cutname).ascii(),  
-	      (const char *)import_tempdat_name,
-	      (const char *)import_tempwav_name,
-	      rdlibrary->srcConverter());
+  if(import_autotrim_box->isChecked()) {
+    settings.setAutotrimLevel(import_autotrim_spin->value());
   }
-  // printf("CMD: %s\n",(const char *)cmd);
-  delete rdlibrary;
+  import_import_conv->setDestinationSettings(&settings);
+  import_import_conv->setUseMetadata(false);
   *import_running=true;
   import_import_aborted=false;
-  import_in_selector_button->setDisabled(true);
-  import_import_button->setDisabled(true);
-  import_cancel_button->setDisabled(true);
-  if(import_normalize_box->isChecked()) {
-    bar_temp_file.setName(import_tempwav_name);
-  }
-  if((import_script_pid=fork())==0) {
-    if(system((const char *)cmd.utf8())==0) {
-      chown(RDCut::pathName(import_cutname),import_config->uid(),
-	    import_config->gid());
-      chmod(RDCut::pathName(import_cutname),
-	    S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH);
+  conv_err=import_import_conv->runImport(import_user->name(),import_user->password(),&audio_conv_err);
+  *import_running=false;
+  StopBar();
+  switch(conv_err) {
+  case RDAudioImport::ErrorOk:
+    if(import_in_metadata_box->isChecked()) {
+      RDWaveFile *wave=new RDWaveFile(import_in_filename_edit->text());
+      wave->openWave(import_wavedata);
+      wave->closeWave();
+      delete wave;
     }
-    else {
-      unlink(import_dest_filename);
-    }
-    exit(0);
-  }
-  else {
-    import_bar->setProgress(0);
-    import_bar->setPercentageVisible(true);
-    import_bar_timer->start(IMPORT_BAR_INTERVAL,true);
-  }
-}
+    QMessageBox::information(this,tr("Import Complete"),
+			     tr("Import complete!"));
+    break;
 
-
-void RDImportAudio::ImportProgress()
-{
-  QString cuts_sql;
-
-  if(*import_running) {
-    if(import_multipass) {
-      import_bar->
-	setProgress((int)(50.0*((double)bar_temp_file.
-				size()/(double)import_temp_length+
-				(double)GetFileSize(import_dest_filename)/
-				(double)import_finished_length)));
-    }
-    else {
-      import_bar->setProgress((int)(100.0*(double)GetFileSize(import_dest_filename)/
-				    (double)import_finished_length));
-    }
-    import_bar_timer->start(IMPORT_BAR_INTERVAL,true);
-  }
-  else {
-    import_bar->setPercentageVisible(false);
-    import_bar->reset();
-    RDCart *cart=new RDCart(import_cutname.left(6).toUInt());
-    RDCut *cut=new RDCut(import_cutname);
-    cut->reset();
-    cut->setOriginName(import_station->name());
-    if(import_autotrim_box->isChecked()) {
-      AutoTrim();
-    }
-
-    //
-    // Update Metadata
-    //
-    if(import_wavedata!=NULL) {
-      cart->setMetadata(import_wavedata);
-      cut->setMetadata(import_wavedata);
-    }
-    delete cut;
-    delete cart;
-    if(QFile::exists(import_dest_filename)) {
-      import_in_selector_button->setEnabled(import_wavedata!=NULL);
-      import_import_button->setEnabled(true);
-      import_cancel_button->setEnabled(true);
-      QMessageBox::information(this,tr("Import Complete"),
-			       tr("Import complete!"));
-    }
-    else {
-      if(import_import_aborted) {
-	QMessageBox::information(this,tr("Import Aborted"),
-				 tr("The import has been aborted."));
-      }
-      else {
-	QMessageBox::warning(this,tr("Import Failed"),
-			     tr("The importer encountered an error.\n\
-Please check your importer configuration and try again."));
-      }
-    }
-    *import_import_metadata=import_in_metadata_box->isChecked();
-    unlink(import_tempwav_name);
-    unlink(import_tempdat_name);
-    done(0);
+  default:
+    QMessageBox::warning(this,tr("Import Error"),
+			 RDAudioImport::errorText(conv_err,audio_conv_err));
   }
+  delete import_import_conv;
+  import_import_conv=NULL;
+  delete cut;
+  import_import_button->setText(tr("Import"));
+  done(0);
 }
 
 
 void RDImportAudio::Export()
 {
-  int format_in=0;
   QString custom_cmd;
+  RDAudioExport::ErrorCode conv_err;
+  RDAudioConvert::ErrorCode audio_conv_err;
 
   if(*import_running) {
     return;
   }
+  import_import_button->setText(tr("Abort"));
 
+  //
+  // Check Before Overwriting
+  //
   import_dest_filename=import_out_filename_edit->text();
   if(QFile::exists(import_dest_filename)) {
     if(QMessageBox::warning(this,tr("File Exists"),
@@ -801,222 +619,78 @@ void RDImportAudio::Export()
       return;
     }
   }
-  RDWaveFile *wave=new RDWaveFile(RDCut::pathName(import_cutname));
-  if(!wave->openWave()) {
-    QMessageBox::warning(this,tr("File Error"),
-			 tr("Cannot open file in archive!"));
-    delete wave;
-    return;
-  }
-  if(wave->type()==RDWaveFile::Unknown) {
-    QMessageBox::warning(this,tr("File Error"),
-			 tr("Unsupported file type in archive!"));
-    wave->closeWave();
-    delete wave;
-    return;
-  }
-  int samplerate=wave->getSamplesPerSec();
-  switch(wave->getFormatTag()) {
-      case WAVE_FORMAT_PCM:
-	format_in=0;
-	import_temp_length=wave->getSampleLength()*
-	  wave->getChannels()*(wave->getBitsPerSample()/8);
-	break;
-
-      case WAVE_FORMAT_MPEG:
-	format_in=wave->getHeadLayer();
-	import_temp_length=wave->getSampleLength()*wave->getChannels()*2;
-	break;
-  }
-  import_import_aborted=false;
-
-  int fd=open(import_dest_filename,
-	      O_RDWR|O_CREAT,S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH);
-  if(fd<0) {
-    QMessageBox::warning(this,tr("No Access"),
-			 tr("Unable to open the file for writing!"),
-			 tr("OK"));
-    return;
-  }
-  ::close(fd);
-  switch(import_settings->format()) {
-    case RDSettings::Pcm16:
-      import_finished_length=
-	(int)(((double)import_temp_length/2.0)*
-	      (double)import_settings->channels()*
-	      (double)import_settings->sampleRate()/44100.0);
-      break;
-      
-    case RDSettings::MpegL1:
-    case RDSettings::MpegL2:
-    case RDSettings::MpegL3:
-      if(import_settings->bitRate()==0) {
-	import_finished_length=
-	  (int)((double)import_temp_length*
-		(double)RDSettings::bytesPerSec(import_station->name(),
-						import_settings->format(),
-						import_settings->quality())/
-		176400.0);
-      }
-      else {
-	import_finished_length=
-	  (int)((double)import_temp_length*
-		(double)import_settings->channels()*
-		(double)import_settings->bitRate()/1411200.0);
-      }
-      break;
-      
-    case RDSettings::Flac:
-    case RDSettings::OggVorbis:
-      import_finished_length=
-	(int)((double)import_temp_length*
-	      (double)RDSettings::bytesPerSec(import_station->name(),
-					      import_settings->format(),
-					      import_settings->quality())/
-	      176400.0);
-      break;
-      
-    default:  // Custom format
-      import_finished_length=0;
-      custom_cmd=import_settings->
-	resolvedCustomCommandLine(RDEscapeString(import_out_filename_edit->
-						 text()));
-      break;
-  }
 
   //
-  // Generate Temporary Filenames
+  // Export
   //
-  QString tempname=tempnam(NULL,IMPORT_TEMP_BASENAME);
-  import_tempwav_name=tempname+".wav";
-  import_tempdat_name=tempname+".dat";
-
-  QString cmd;
-  float normal=0.0;
-  RDLibraryConf *rdlibrary=new RDLibraryConf(import_station->name(),0);
-  if(import_normalize_box->isChecked()) {
-    normal=pow(10.0,(double)(import_normalize_spin->value())/20.0);
-    import_multipass=true;
-    cmd=QString().
-      sprintf("rd_export_file %6.4f %d %d %s %d %d %d %d %d %s %s %s %d",
-	      normal,
-	      format_in,
-	      samplerate,
-	      RDCut::pathName(import_cutname).ascii(),  
-	      import_settings->format(),
-	      import_settings->channels(),
-	      import_settings->sampleRate(),
-	      import_settings->bitRate()/1000,
-	      import_settings->quality(),
-	      (const char *)RDEscapeString(import_out_filename_edit->text()).utf8(),
-	      (const char *)import_tempdat_name,
-	      (const char *)import_tempwav_name,
-	      rdlibrary->srcConverter());
-  }
-  else {
-    import_multipass=false;
-    cmd=QString().
-      sprintf("rd_export_file 0 %d %d %s %d %d %d %d %d %s %s %s %d",
-	      format_in,
-	      samplerate,
-	      RDCut::pathName(import_cutname).ascii(),  
-	      import_settings->format(),
-	      import_settings->channels(),
-	      import_settings->sampleRate(),
-	      import_settings->bitRate()/1000,
-	      import_settings->quality(),
-	      (const char *)RDEscapeString(import_out_filename_edit->text()).utf8(),  
-	      (const char *)import_tempdat_name,
-	      (const char *)import_tempwav_name,
-	      rdlibrary->srcConverter());
-  }
-  delete rdlibrary;
-  if(!custom_cmd.isEmpty()) {
-    cmd+=" \""+custom_cmd+"\"";
-    import_bar->setDisabled(true);
-  }
-  //printf("CMD: %s\n",(const char *)cmd);
+  StartBar();
+  RDCut *cut=new RDCut(import_cutname);
+  import_export_conv=new RDAudioExport(import_station,this);
+  import_export_conv->setCartNumber(cut->cartNumber());
+  import_export_conv->setCutNumber(cut->cutNumber());
+  import_export_conv->setDestinationFile(import_dest_filename);
+  import_export_conv->setDestinationSettings(import_settings);
+  import_export_conv->setRange(cut->startPoint(),cut->endPoint());
+  import_export_conv->setEnableMetadata(import_out_metadata_box->isChecked());
   *import_running=true;
   import_import_aborted=false;
-  import_out_selector_button->setDisabled(true);
-  import_import_button->setDisabled(true);
-  import_cancel_button->setDisabled(true);
-  if(import_normalize_box->isChecked()) {
-    bar_temp_file.setName(import_tempwav_name);
-  }
-  if((import_script_pid=fork())==0) {
-    if(system((const char *)cmd.utf8())!=0) {
-      unlink(import_dest_filename);
-    }
-    exit(0);
-  }
-  else {
-    import_bar->setProgress(0);
-    import_bar->setPercentageVisible(true);
-    import_bar_timer->start(IMPORT_BAR_INTERVAL,true);
-  }
-}
+  conv_err=import_export_conv->runExport(import_user->name(),
+					 import_user->password(),
+					 &audio_conv_err);
+  *import_running=false;
+  StopBar();
+  switch(conv_err) {
+  case RDAudioExport::ErrorOk:
+    QMessageBox::information(this,tr("Export Complete"),
+			     tr("Export complete!"));
+    break;
 
-
-void RDImportAudio::ExportProgress()
-{
-  if(*import_running) {
-    if(import_multipass) {
-      import_bar->
-	setProgress((int)(50.0*((double)bar_temp_file.
-				size()/(double)import_temp_length+
-				(double)GetFileSize(import_dest_filename)/
-				(double)import_finished_length)));
-    }
-    else {
-      import_bar->setProgress((int)(100.0*(double)GetFileSize(import_dest_filename)/
-				    (double)import_finished_length));
-    }
-    import_bar_timer->start(IMPORT_BAR_INTERVAL,true);
+  default:
+    QMessageBox::warning(this,tr("Export Error"),
+			 RDAudioExport::errorText(conv_err,audio_conv_err));
   }
-  else {
-    import_bar->setPercentageVisible(false);
-    import_bar->reset();
-    if(QFile::exists(import_dest_filename)) {
-      import_out_selector_button->setEnabled(true);
-      import_import_button->setEnabled(true);
-      import_cancel_button->setEnabled(true);
-      QMessageBox::information(this,tr("Export Complete"),
-			       tr("Export complete!"));
-    }
-    else {
-      if(import_import_aborted) {
-	QMessageBox::information(this,tr("Export Aborted"),
-				 tr("The export has been aborted."));
-      }
-      else {
-	QMessageBox::warning(this,tr("Export Failed"),
-			     tr("The Exporter encountered an error.\n\
-Please check your configuration and try again."));
-      }
-    }
-    unlink(import_tempwav_name);
-    unlink(import_tempdat_name);
-    done(0);
-  }
-}
-
-
-void RDImportAudio::AutoTrim()
-{
-  RDCut *cut=new RDCut(import_cutname);
-  cut->autoTrim(RDCut::AudioBoth,100*import_autotrim_spin->value());
+  delete import_export_conv;
+  import_export_conv=NULL;
   delete cut;
+  import_import_button->setText(tr("Export"));
+  done(0);
 }
 
 
-unsigned RDImportAudio::GetFileSize(const QString &filename)
+void RDImportAudio::StartBar()
 {
-  struct stat stat_data;
+  import_bar->setEnabled(true);
+  import_bar->activate(true);
+  import_importmode_button->setDisabled(true);
+  import_exportmode_button->setDisabled(true);
+  import_in_filename_label->setDisabled(true);
+  import_in_filename_edit->setDisabled(true);
+  import_in_metadata_box->setDisabled(true);
+  import_in_selector_button->setDisabled(true);
+  import_channels_label->setDisabled(true);
+  import_out_filename_label->setDisabled(true);
+  import_out_filename_edit->setDisabled(true);
+  import_out_metadata_box->setDisabled(true);
+  import_out_selector_button->setDisabled(true);
+  import_format_label->setDisabled(true);
+  import_format_edit->setDisabled(true);
+  import_out_format_button->setDisabled(true);
+  import_normalize_box->setDisabled(true);
+  import_normalize_spin->setDisabled(true);
+  import_normalize_label->setDisabled(true);
+  import_normalize_unit->setDisabled(true);
+  import_autotrim_box->setDisabled(true);
+  import_autotrim_spin->setDisabled(true);
+  import_autotrim_label->setDisabled(true);
+  import_autotrim_unit->setDisabled(true);
+  import_channels_box->setDisabled(true);
+  import_cancel_button->setDisabled(true);
+  //  import_import_button->setDisabled(true);
+}
 
-  memset(&stat_data,0,sizeof(stat_data));
-  if(stat(filename,&stat_data)<0) {
-    return 0;
-  }
-  return stat_data.st_size;
+
+void RDImportAudio::StopBar()
+{
+  import_bar->activate(false);
+  import_bar->setDisabled(true);
 }
