@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsvc.cpp,v 1.66.2.5 2009/02/12 14:21:26 cvs Exp $
+//      $Id: rdsvc.cpp,v 1.71.8.2 2013/01/14 16:35:58 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -67,6 +67,19 @@ void RDSvc::setDescription(const QString &desc) const
 }
 
 
+QString RDSvc::programCode() const
+{
+  return RDGetSqlValue("SERVICES","NAME",svc_name,"PROGRAM_CODE").
+    toString();
+}
+
+
+void RDSvc::setProgramCode(const QString &str) const
+{
+  SetRow("PROGRAM_CODE",str);
+}
+
+
 QString RDSvc::nameTemplate() const
 {
   return RDGetSqlValue("SERVICES","NAME",svc_name,"NAME_TEMPLATE").
@@ -93,6 +106,19 @@ void RDSvc::setTrackGroup(const QString &group) const
 }
 
 
+QString RDSvc::autospotGroup() const
+{
+  return RDGetSqlValue("SERVICES","NAME",svc_name,"AUTOSPOT_GROUP").
+    toString();
+}
+
+
+void RDSvc::setAutospotGroup(const QString &group) const
+{
+  SetRow("AUTOSPOT_GROUP",group);
+}
+
+
 bool RDSvc::autoRefresh() const
 {
   return RDBool(RDGetSqlValue("SERVICES","NAME",svc_name,"AUTO_REFRESH").
@@ -143,6 +169,21 @@ void RDSvc::setChainto(bool state) const
 }
 
 
+QString RDSvc::importTemplate(ImportSource src) const
+{
+  QString fieldname=SourceString(src)+"IMPORT_TEMPLATE";
+  return RDGetSqlValue("SERVICES","NAME",svc_name,fieldname).
+    toString();
+}
+
+
+void RDSvc::setImportTemplate(ImportSource src,const QString &str) const
+{
+  QString fieldname=SourceString(src)+"IMPORT_TEMPLATE";
+  SetRow(fieldname,str);
+}
+
+
 QString RDSvc::breakString() const
 {
   return RDGetSqlValue("SERVICES","NAME",svc_name,"MUS_BREAK_STRING").
@@ -201,7 +242,7 @@ void RDSvc::setTrackCart(ImportSource src,const QString &str)
 
 QString RDSvc::importPath(ImportSource src,ImportOs os) const
 {
-  QString fieldname=SourceString(src)+OsString(os);
+  QString fieldname=SourceString(src)+OsString(os)+"PATH";
   return RDGetSqlValue("SERVICES","NAME",svc_name,fieldname).
     toString();
 }
@@ -210,7 +251,23 @@ QString RDSvc::importPath(ImportSource src,ImportOs os) const
 void RDSvc::setImportPath(ImportSource src,ImportOs os,const QString &path) 
   const
 {
-  QString fieldname=SourceString(src)+OsString(os);
+  QString fieldname=SourceString(src)+OsString(os)+"PATH";
+  SetRow(fieldname,path);
+}
+
+
+QString RDSvc::preimportCommand(ImportSource src,ImportOs os) const
+{
+  QString fieldname=SourceString(src)+OsString(os)+"PREIMPORT_CMD";
+  return RDGetSqlValue("SERVICES","NAME",svc_name,fieldname).
+    toString();
+}
+
+
+void RDSvc::setPreimportCommand(ImportSource src,ImportOs os,
+				const QString &path) const
+{
+  QString fieldname=SourceString(src)+OsString(os)+"PREIMPORT_CMD";
   SetRow(fieldname,path);
 }
 
@@ -297,6 +354,7 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
   char annctype_buf[RD_MAX_IMPORT_LINE_LENGTH];
   QString os_flag;
   int cartlen;
+  QString sql;
 
   //
   // Set Import Source
@@ -321,87 +379,121 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
   //
   // Load Parser Parameters
   //
-  QString sql=
-    QString().sprintf("select %s%s_PATH,%s_CART_OFFSET,%s_CART_LENGTH,\
-                       %s_DATA_OFFSET,%s_DATA_LENGTH,\
-                       %s_EVENT_ID_OFFSET,%s_EVENT_ID_LENGTH,\
-                       %s_ANNC_TYPE_OFFSET,%s_ANNC_TYPE_LENGTH,\
-                       %s_TITLE_OFFSET,%s_TITLE_LENGTH,\
-                       %s_LABEL_CART,%s_TRACK_CART,\
-                       %s_HOURS_OFFSET,%s_HOURS_LENGTH,\
-                       %s_MINUTES_OFFSET,%s_MINUTES_LENGTH,\
-                       %s_SECONDS_OFFSET,%s_SECONDS_LENGTH,\
-                       %s_LEN_HOURS_OFFSET,%s_LEN_HOURS_LENGTH,\
-                       %s_LEN_MINUTES_OFFSET,%s_LEN_MINUTES_LENGTH,\
-                       %s_LEN_SECONDS_OFFSET,%s_LEN_SECONDS_LENGTH \
-                       from SERVICES where NAME=\"%s\"",
-		      (const char *)src_str,
-		      (const char *)os_flag,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)src_str,
-		      (const char *)RDEscapeString(svc_name));
+  sql=QString().sprintf("select %s%s_PATH,\
+                         %s_LABEL_CART,\
+                         %s_TRACK_CART,\
+                         %s%s_PREIMPORT_CMD \
+                         from SERVICES where NAME=\"%s\"",
+			(const char *)src_str,
+			(const char *)os_flag,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)os_flag,
+			(const char *)RDEscapeString(svc_name));
   RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     return false;
   }
   QString infilename=q->value(0).toString();
-  int cart_offset=q->value(1).toInt();
-  int cart_length=q->value(2).toInt();
+  QString label_cart=q->value(1).toString().stripWhiteSpace();
+  QString track_cart=q->value(2).toString().stripWhiteSpace();
+  QString preimport_cmd=q->value(3).toString();
+  delete q;
+
+  //
+  // Run Preimport Command
+  //
+  if(!preimport_cmd.isEmpty()) {
+    system(RDDateDecode(preimport_cmd,date));
+  }
+
+  QString parser_table;
+  QString parser_name;
+  if(importTemplate(src).isEmpty()) {
+    src_str+="_";
+    parser_table="SERVICES";
+    parser_name=svc_name;
+  }
+  else {
+    src_str="";
+    parser_table="IMPORT_TEMPLATES";
+    parser_name=importTemplate(src);
+  }
+  sql=QString().sprintf("select %sCART_OFFSET,%sCART_LENGTH,\
+                         %sDATA_OFFSET,%sDATA_LENGTH,		\
+                         %sEVENT_ID_OFFSET,%sEVENT_ID_LENGTH,	\
+                         %sANNC_TYPE_OFFSET,%sANNC_TYPE_LENGTH,	\
+                         %sTITLE_OFFSET,%sTITLE_LENGTH,\
+                         %sHOURS_OFFSET,%sHOURS_LENGTH,\
+                         %sMINUTES_OFFSET,%sMINUTES_LENGTH,\
+                         %sSECONDS_OFFSET,%sSECONDS_LENGTH,\
+                         %sLEN_HOURS_OFFSET,%sLEN_HOURS_LENGTH,\
+                         %sLEN_MINUTES_OFFSET,%sLEN_MINUTES_LENGTH,\
+                         %sLEN_SECONDS_OFFSET,%sLEN_SECONDS_LENGTH \
+                         from %s where NAME=\"%s\"",
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)src_str,
+			(const char *)parser_table,
+			(const char *)RDEscapeString(parser_name));
+  q=new RDSqlQuery(sql);
+  if(!q->first()) {
+    delete q;
+    return false;
+  }
+  int cart_offset=q->value(0).toInt();
+  int cart_length=q->value(1).toInt();
   unsigned cart_size=cart_offset+cart_length;
-  int data_offset=q->value(3).toInt();
-  int data_length=q->value(4).toInt();
+  int data_offset=q->value(2).toInt();
+  int data_length=q->value(3).toInt();
   unsigned data_size=data_offset+data_length;
-  int eventid_offset=q->value(5).toInt();
-  int eventid_length=q->value(6).toInt();
+  int eventid_offset=q->value(4).toInt();
+  int eventid_length=q->value(5).toInt();
   unsigned eventid_size=eventid_offset+eventid_length;
-  int annctype_offset=q->value(7).toInt();
-  int annctype_length=q->value(8).toInt();
+  int annctype_offset=q->value(6).toInt();
+  int annctype_length=q->value(7).toInt();
   unsigned annctype_size=annctype_offset+annctype_length;
-  int title_offset=q->value(9).toInt();
-  int title_length=q->value(10).toInt();
+  int title_offset=q->value(8).toInt();
+  int title_length=q->value(9).toInt();
   unsigned title_size=title_offset+title_length;
-  QString label_cart=q->value(11).toString().stripWhiteSpace();
-  QString track_cart=q->value(12).toString().stripWhiteSpace();
-  int hours_offset=q->value(13).toInt();
-  int hours_length=q->value(14).toInt();
+  int hours_offset=q->value(10).toInt();
+  int hours_length=q->value(11).toInt();
   unsigned hours_size=hours_offset+hours_length;
-  int minutes_offset=q->value(15).toInt();
-  int minutes_length=q->value(16).toInt();
+  int minutes_offset=q->value(12).toInt();
+  int minutes_length=q->value(13).toInt();
   unsigned minutes_size=minutes_offset+minutes_length;
-  int seconds_offset=q->value(17).toInt();
-  int seconds_length=q->value(18).toInt();
+  int seconds_offset=q->value(14).toInt();
+  int seconds_length=q->value(15).toInt();
   unsigned seconds_size=seconds_offset+seconds_length;
-  int hours_len_offset=q->value(19).toInt();
-  int hours_len_length=q->value(20).toInt();
+  int hours_len_offset=q->value(16).toInt();
+  int hours_len_length=q->value(17).toInt();
   unsigned hours_len_size=hours_len_offset+hours_len_length;
-  int minutes_len_offset=q->value(21).toInt();
-  int minutes_len_length=q->value(22).toInt();
+  int minutes_len_offset=q->value(18).toInt();
+  int minutes_len_length=q->value(19).toInt();
   unsigned minutes_len_size=minutes_len_offset+minutes_len_length;
-  int seconds_len_offset=q->value(23).toInt();
-  int seconds_len_length=q->value(24).toInt();
+  int seconds_len_offset=q->value(20).toInt();
+  int seconds_len_length=q->value(21).toInt();
   unsigned seconds_len_size=seconds_len_offset+seconds_len_length;
 
   delete q;
@@ -428,9 +520,9 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
                          INSERT_FIRST int unsigned default 0,\
                          TRACK_STRING char(255),\
                          EXT_DATA char(32),\
-                         EXT_EVENT_ID char(8),\
+                         EXT_EVENT_ID char(32),\
                          EXT_ANNC_TYPE char(8),\
-                         EXT_CART_NAME char(8),\
+                         EXT_CART_NAME char(32),\
                          EVENT_USED enum('N','Y') default 'N',\
                          INDEX START_TIME_IDX (START_HOUR,START_SECS))",
 			(const char *)dest_table);
@@ -971,8 +1063,9 @@ void RDSvc::create(const QString exemplar) const
   RDSqlQuery *q1;
 
   if(exemplar.isEmpty()) {  // Create Empty Service
-    sql=QString().sprintf("insert into SERVICES set NAME=\"%s\"",
-			  (const char *)RDEscapeString(svc_name));
+    sql=QString("insert into SERVICES set NAME=\"")+
+      RDEscapeString(svc_name)+"\","+
+      "NAME_TEMPLATE=\""+RDEscapeString(svc_name)+"-%m%d\"";
     q=new RDSqlQuery(sql);
     delete q;
 
@@ -1232,7 +1325,7 @@ void RDSvc::remove() const
 		      (const char *)RDEscapeString(svc_name));
   q=new RDSqlQuery(sql);
   delete q;
-  sql=QString().sprintf("update RDAIRPLAY set DEFAULT_SERVICE="" \
+  sql=QString().sprintf("update RDAIRPLAY set DEFAULT_SERVICE=\"\" \
                          where DEFAULT_SERVICE=\"%s\"",
 			(const char *)RDEscapeString(svc_name));
   q=new RDSqlQuery(sql);
@@ -1321,11 +1414,11 @@ QString RDSvc::OsString(ImportOs os) const
   QString fieldname;
   switch(os) {
       case RDSvc::Linux:
-	fieldname="PATH";
+	fieldname="";
 	break;
 
       case RDSvc::Windows:
-	fieldname="WIN_PATH";
+	fieldname="WIN_";
 	break;
   }
   return fieldname;
