@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdwavefile.cpp,v 1.13.2.6 2010/01/22 21:04:15 cvs Exp $
+//    $Id: rdwavefile.cpp,v 1.24 2011/01/25 19:28:48 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -30,10 +30,13 @@
 #include <math.h>
 #include <fcntl.h>
 #include <arpa/inet.h>
+#include <unistd.h>
 
 #include <id3/tag.h>
 #include <id3/misc_support.h>
+#ifdef HAVE_FLAC
 #include <FLAC/metadata.h>
+#endif  // HAVE_FLAC
 
 #include <qobject.h>
 #include <qstring.h>
@@ -54,6 +57,7 @@ RDWaveFile::RDWaveFile(QString file_name)
   format_chunk=false;
   format_tag=0;
   channels=0;
+  normalize_level=1.0;
   samples_per_sec=0;
   avg_bytes_per_sec=0;
   block_align=0;
@@ -203,6 +207,7 @@ bool RDWaveFile::openWave(RDWaveData *data)
   if(!wave_file.open(IO_ReadOnly)) {
     return false;
   }
+
   switch(GetType(wave_file.handle())) {
       case RDWaveFile::Wave:
 	if(GetFmt(wave_file.handle())) {
@@ -218,8 +223,13 @@ bool RDWaveFile::openWave(RDWaveData *data)
 	data_chunk=true;
 	data_start=lseek(wave_file.handle(),0,SEEK_CUR);
 	if((!GetFact(wave_file.handle()))||(sample_length==0)) {
-	  if((format_tag!=WAVE_FORMAT_PCM)&&format_chunk) {
+
+
+	  if((format_tag!=WAVE_FORMAT_PCM)&&
+	     (format_tag!=WAVE_FORMAT_IEEE_FLOAT)&&format_chunk) {
 #ifdef MPEG_FACT_FUDGE
+
+	    
 	    // Guesstimate the overall sample size
 	    time_length=data_length/avg_bytes_per_sec;
 	    sample_length=time_length*samples_per_sec;
@@ -267,7 +277,6 @@ bool RDWaveFile::openWave(RDWaveData *data)
 	GetCart(wave_file.handle());
 	GetBext(wave_file.handle());
 	GetMext(wave_file.handle());
-//	GetLevl(wave_file.handle());
 	GetList(wave_file.handle());
 	GetScot(wave_file.handle());
 	GetAv10(wave_file.handle());
@@ -316,6 +325,7 @@ bool RDWaveFile::openWave(RDWaveData *data)
 	data_chunk=true;
 	format_chunk=true;
 	wave_type=RDWaveFile::Ogg;
+        ReadNormalizeLevel(wave_file.name());
 	ValidateMetadata();
 	return true;
 #else
@@ -364,7 +374,7 @@ bool RDWaveFile::openWave(RDWaveData *data)
 	wave_type=RDWaveFile::Tmc;
 	ReadTmcMetadata(wave_file.handle());
 	break;
-
+#ifdef HAVE_FLAC
       case RDWaveFile::Flac:
 	format_tag=WAVE_FORMAT_FLAC;
 	if(!GetFlacStreamInfo()) {
@@ -373,9 +383,12 @@ bool RDWaveFile::openWave(RDWaveData *data)
 	}
 	wave_type=RDWaveFile::Flac;
 	format_chunk=true;
-	ReadId3Metadata();
-	ReadFlacMetadata();
+	if(wave_data!=NULL) {
+	  ReadId3Metadata();
+	  ReadFlacMetadata();
+	}
 	break;
+#endif  // HAVE_FLAC
 
       default:
 	close(wave_file.handle());
@@ -385,6 +398,9 @@ bool RDWaveFile::openWave(RDWaveData *data)
   lseek(wave_file.handle(),data_start,SEEK_SET);
   ValidateMetadata();
 
+  //  lseek(wave_file.handle(),SEEK_SET,0x845);
+  //  printf("PTR: 0x%04X\n",lseek(wave_file.handle(),SEEK_CUR,0));
+
   return true;
 }
 
@@ -430,6 +446,7 @@ bool RDWaveFile::createWave(RDWaveData *data)
 	}
         prev_mask = umask(0113);      // Set umask so files are user and group writable.
         rc=wave_file.open(IO_ReadWrite|IO_Truncate);
+	unlink((wave_file.name()+".energy").ascii());
         umask(prev_mask);
 	if(rc==false) {
 	  return false;
@@ -669,6 +686,7 @@ void RDWaveFile::closeWave(int samples)
   format_chunk=false;
   format_tag=0;
   channels=0;
+  normalize_level=1.0;
   samples_per_sec=0;
   avg_bytes_per_sec=0;
   block_align=0;
@@ -854,11 +872,23 @@ int RDWaveFile::readWave(void *buf,int count)
   int n;
   unsigned int pos;
   int c = 0;
+  int16_t *sample;
 
   switch(wave_type) {
       case RDWaveFile::Ogg:
 #ifdef HAVE_VORBIS
-	n=ov_read(&vorbis_file,(char *)buf,count,0,2,1,&stream);
+        n = 0;
+        while(n!=count){
+          int ret = ov_read(&vorbis_file,(char *)buf+n,count-n,0,2,1,&stream);
+	  if (!ret) break;
+	    n+=ret;
+	}
+        if(normalize_level != 1.0f){
+          for (int i=0;i<n/2;i++) {
+            sample=(int16_t *)buf+i;
+            *sample=(int16_t)(normalize_level*(double)*sample);
+	  }
+        }
 	return n;
 #endif  // HAVE_VORBIS
 	return 0;
@@ -887,6 +917,8 @@ int RDWaveFile::readWave(void *buf,int count)
     }
   }
 
+  //  printf("RDWaveFile: 0x%02X\n",((char *)buf)[0]&0xff);
+
   return c;
 }
 
@@ -1083,6 +1115,53 @@ int RDWaveFile::endTrim(int level)
 }
 
 
+void RDWaveFile::getSettings(RDSettings *settings)
+{
+  switch(type()) {
+  case RDWaveFile::Pcm8:
+    // FIXME
+    break;
+
+  case RDWaveFile::Wave:
+    switch(getFormatTag()) {
+    case WAVE_FORMAT_PCM:
+      settings->setFormat(RDSettings::Pcm16);
+      break;
+
+    case WAVE_FORMAT_MPEG:
+      settings->setFormat((RDSettings::Format)getHeadLayer());
+      break;
+    }
+    break;
+
+  case RDWaveFile::Mpeg:
+  case RDWaveFile::Atx:
+  case RDWaveFile::Tmc:
+  case RDWaveFile::Ambos:
+    settings->setFormat((RDSettings::Format)getHeadLayer());
+    break;
+
+  case RDWaveFile::Ogg:
+    settings->setFormat(RDSettings::OggVorbis);
+    break;
+#ifdef HAVE_FLAC
+  case RDWaveFile::Flac:
+    settings->setFormat(RDSettings::Flac);
+    break;
+#endif  // HAVE_FLAC
+  }
+  settings->setChannels(getChannels());
+  settings->setSampleRate(getSamplesPerSec());
+  settings->setLayer(getHeadLayer());
+  settings->setBitRate(getHeadBitRate());
+}
+
+
+void RDWaveFile::setSettings(const RDSettings *settings)
+{
+}
+
+
 int RDWaveFile::seekWave(int offset,int whence)
 {
   int pos;
@@ -1093,10 +1172,10 @@ int RDWaveFile::seekWave(int offset,int whence)
 	switch(whence) {
 	    case SEEK_SET:
 	      if(ov_pcm_seek(&vorbis_file,offset/(2*channels))==0) {
-	      printf("RDWaveFile::seekWave() = %d\n",offset);
+		//printf("RDWaveFile::seekWave() = %d\n",offset);
 		return offset;
 	      }
-	      printf("RDWaveFile::seekWave() = -1\n");
+	      //printf("RDWaveFile::seekWave() = -1\n");
 	      return -1;
 	      break;
 
@@ -1168,7 +1247,6 @@ int RDWaveFile::seekWave(int offset,int whence)
 } 
 
 
-
 unsigned short RDWaveFile::getFormatTag() const
 {
   return format_tag;
@@ -1983,20 +2061,17 @@ bool RDWaveFile::IsMpeg(int fd)
   if((buffer[0]==0xFF)&&((buffer[1]&0xE0)==0xE0)) {
     return true;
   }
-//  if(buffer[0]==0) {   // Possibly a broken null-padded ID3 tag -- see if
-                       // we can find the start of the MPEG data
-    while(read(fd,buffer,1)==1) {
-      if(buffer[0]==0xFF) {  // Could be it -- check the next byte
-	if(read(fd,buffer,1)==1) {
-	  if((buffer[0]&0xF0)==0xF0) {  // Got it -- fix things up
-	    id3v2_tag[0]=true;
-	    id3v2_offset[0]=lseek(fd,0,SEEK_CUR)-2;
-	    return true;
-	  }
+  while(read(fd,buffer,1)==1) {
+    if(buffer[0]==0xFF) {  // Could be it -- check the next byte
+      if(read(fd,buffer,1)==1) {
+	if((buffer[0]&0xF0)==0xF0) {  // Got it -- fix things up
+	  id3v2_tag[0]=true;
+	  id3v2_offset[0]=lseek(fd,0,SEEK_CUR)-2;
+	  return true;
 	}
       }
     }
-//  }
+  }
   return false;
 }
 
@@ -2048,6 +2123,7 @@ bool RDWaveFile::IsTmc(int fd)
 
 bool RDWaveFile::IsFlac(int fd)
 {
+#ifdef HAVE_FLAC
   char buffer[5];
 
   ID3_Tag id3_tag(QCString().sprintf("%s",(const char *)wave_file.name().utf8()));
@@ -2060,6 +2136,9 @@ bool RDWaveFile::IsFlac(int fd)
     return false;
   }
   return true;
+#else
+  return false;
+#endif  // HAVE_FLAC
 }
 
 
@@ -2122,7 +2201,7 @@ void RDWaveFile::WriteChunk(int fd,char *cname,unsigned char *buf,unsigned size)
     write(fd,buf,size);
     return;
   }
-  printf("WARNING: Updated chunk size mismatch!  Update not written.\n");
+  //printf("WARNING: Updated chunk size mismatch!  Update not written.\n");
 }
 
 
@@ -3485,6 +3564,7 @@ bool RDWaveFile::GetMpegHeader(int fd,int offset)
   // Frame Size (without padding)
   //
   mpeg_frame_size=144*head_bit_rate/samples_per_sec;
+
   return true;
 }
 
@@ -3506,6 +3586,7 @@ int RDWaveFile::GetAtxOffset(int fd)
 
 bool RDWaveFile::GetFlacStreamInfo()
 {
+#if HAVE_FLAC
   FLAC__StreamMetadata sinfo;
   if(!FLAC__metadata_get_streaminfo(QCString().sprintf("%s",(const char *)wave_file.name().utf8()),&sinfo)) {
     return false;
@@ -3515,6 +3596,9 @@ bool RDWaveFile::GetFlacStreamInfo()
   sample_length=sinfo.data.stream_info.total_samples;
   channels=sinfo.data.stream_info.channels;
   return true;
+#else
+  return false;
+#endif  // HAVE_FLAC
 }
 
 
@@ -3950,6 +4034,8 @@ void RDWaveFile::GetEnergy()
 {
   int file_ptr;
 
+  ReadEnergyFile(wave_file.name());
+  
   if(!levl_chunk) {
     GetLevl(wave_file.handle());
   }
@@ -4029,6 +4115,29 @@ unsigned RDWaveFile::LoadEnergy()
 	return i;
 	break;
 
+      case WAVE_FORMAT_VORBIS:
+	block_size=2304*channels;
+	while(i<energy_size) {
+	  if(readWave(pcm,block_size)!=block_size) {
+	    has_energy=true;
+	    return i;
+	  }
+	  for(int j=0;j<channels;j++) {
+	    max=0;
+	    energy_data.push_back(0);
+	    for(int k=0;k<1152;k++) {
+	      offset=2*k*channels+2*j;
+	      if((pcm[offset]+256*pcm[offset+1])>energy_data[i]) {
+		energy_data[i]=pcm[offset]+256*pcm[offset+1];
+	      }
+	    }
+	    i++;
+	  }
+	}
+	has_energy=true;
+	return i;
+	break;
+
       default:
 	has_energy=false;
 	return 0;
@@ -4037,6 +4146,66 @@ unsigned RDWaveFile::LoadEnergy()
 }
 
 
+bool RDWaveFile::ReadEnergyFile(QString wave_file_name)
+{
+  if(has_energy && energy_loaded) return true;
+
+  QFile energy_file;
+  QString str;
+  unsigned char frame[50];
+
+  energy_file.setName(wave_file_name+".energy");
+  if(!energy_file.open(IO_ReadOnly)) 
+    return false;
+  if(energy_file.readLine(str,20) <= 0)
+     return false;
+  normalize_level=str.toDouble();
+  energy_file.close();
+  if(!energy_file.open(IO_ReadOnly)) 
+    return false;
+  read(energy_file.handle(),frame,str.length());
+  int i=0;
+  while(read(energy_file.handle(),frame,2)>0) {
+      energy_data.push_back(frame[0]+256*frame[1]);
+      i++;
+  }
+  ext_time_length=
+   	(unsigned)(1000.0*(((double)i*1152)/getChannels())/(double)samples_per_sec);  
+  energy_file.close();
+  energy_loaded=true;
+  has_energy=true;
+  return true;
+}
+
+
+bool RDWaveFile::ReadNormalizeLevel(QString wave_file_name)
+{
+  QFile energy_file;
+  QString str;
+
+  energy_file.setName(wave_file_name+".energy");
+  if(!energy_file.open(IO_ReadOnly)) 
+    return false;
+  if(energy_file.readLine(str,20) <= 0)
+     return false;
+  normalize_level=str.toDouble();
+  energy_file.close();
+  return true;
+}
+
+
+double RDWaveFile::getNormalizeLevel() const
+{
+  return normalize_level;
+}
+
+
+void RDWaveFile::setNormalizeLevel(double level)
+{
+  normalize_level=level;
+}
+
+
 void RDWaveFile::GrowAlloc(size_t size)
 {
   if(size>(size_t)cook_buffer_size) {
