@@ -23,11 +23,17 @@
 #include <stdio.h>
 #include <string.h>
 #include <sys/time.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 
 #include <qdatetime.h>
+#include <qstringlist.h>
 
 #include <rduser.h>
 #include <rddb.h>
+#include <rdconf.h>
+#include <rdwebresult.h>
 
 #include <rdweb.h>
 
@@ -88,7 +94,7 @@ int RDPutPostString(char *sPost,char *sArg,char *sValue,int dMaxSize)
      * Will it fit?
      */
     dOrigin=strlen(sPost);
-    if((dOrigin+strlen(sArg)+strlen(sValue)+2)>=dMaxSize) {
+    if((dOrigin+strlen(sArg)+strlen(sValue)+2)>=(unsigned)dMaxSize) {
       return -1;
     }
     /*
@@ -130,7 +136,7 @@ int RDPutPostString(char *sPost,char *sArg,char *sValue,int dMaxSize)
  *          -1 if the search is unsuccessful
  */
 
-int RDFindPostString(char *cBuffer,char *sSearch,char *sReturn,int dReturnSize)
+int RDFindPostString(const char *cBuffer,const char *sSearch,char *sReturn,int dReturnSize)
 
 {
   int i=0,j=0;
@@ -184,7 +190,8 @@ int RDFindPostString(char *cBuffer,char *sSearch,char *sReturn,int dReturnSize)
  *          -1 if the search is unsuccessful
  */
 
-int RDGetPostString(char *cBuffer,char *sSearch,char *sReturn,int dReturnSize)
+int RDGetPostString(const char *cBuffer,const char *sSearch,
+		    char *sReturn,int dReturnSize)
 {
   if(RDFindPostString(cBuffer,sSearch,sReturn,dReturnSize)<0) {
     return -1;
@@ -206,7 +213,7 @@ int RDGetPostString(char *cBuffer,char *sSearch,char *sReturn,int dReturnSize)
  *          -1 if the search is unsuccessful
  */
 
-int RDGetPostInt(char *cBuffer,char *sSearch,int *dReturn)
+int RDGetPostInt(const char *cBuffer,const char *sSearch,int *dReturn)
 {
   char sAccum[256];
 
@@ -222,7 +229,7 @@ int RDGetPostInt(char *cBuffer,char *sSearch,int *dReturn)
 
 
 
-int RDGetPostLongInt(char *cBuffer,char *sSearch,long int *dReturn)
+int RDGetPostLongInt(const char *cBuffer,const char *sSearch,long int *dReturn)
 {
   char sAccum[256];
 
@@ -520,31 +527,48 @@ int RDPurgePlaintext(char *sPost,int dMaxSize)
 
 
 
-void RDCgiError(const char *sError)
+void RDCgiError(const char *str,int resp_code)
 {
   /* The cgi header */
   printf("Content-type: text/html\n");
+  printf("Status: %d\n",resp_code);
   printf("\n");
 
   /* The html header */
   printf("<html>\n");
   printf("<head>\n");
   printf("<title>");
-  printf("CGI Internal Error");
+  printf("CGI Internal Error %d",resp_code);
   printf("</title>\n");
   printf("</head>\n");
 
   /* The body of the message */
   printf("<h1>Oops!</h1><br>\n");
   printf("We seem to have encountered a problem!  The system says: <br>\n");
-  printf("<pre>%s</pre><br>\n",sError);
+  printf("<pre>%d<br>%s</pre><br>\n",resp_code,str);
 
   /* The html footer */
   printf("</body>\n");
-  exit(1);
+  exit(0);
 }
 
 
+#ifndef WIN32
+extern void RDXMLResult(const char *str,int resp_code,
+			RDAudioConvert::ErrorCode err)
+{
+  RDWebResult *we=new RDWebResult(str,resp_code,err);
+
+  printf("Content-type: application/xml\n");
+  printf("Status: %d\n",resp_code);
+  printf("\n");
+  printf("%s",(const char *)we->xml());
+  delete we;
+
+  exit(0);
+}
+#endif  // WIN32
+
 
 /*
  * int BufferDiff(char sString,int dOrigin,int dDiff,int dMaxSize)
@@ -672,6 +696,7 @@ long int RDAuthenticateLogin(const QString &username,const QString &passwd,
 				(const char *)addr.toString());
   RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
+
   return session;
 }
 
@@ -757,3 +782,291 @@ QString RDEscapeWebString(const QString &str)
   ret.replace("\"","&quot;");
   return ret;
 }
+
+
+bool RDParsePost(std::map<QString,QString> *vars)
+{
+  std::map<QString,QString> headers;
+  bool header=true;
+  FILE *f=NULL;
+  char *data=NULL;
+  ssize_t n=0;
+  QString sep;
+  QString name;
+  QString filename;
+  QString tempdir;
+  int fd=-1;
+
+  //
+  // Initialize Temp Directory Path
+  //
+  if(getenv("TMPDIR")!=NULL) {
+    tempdir=getenv("TMPDIR");
+  }
+  else {
+    tempdir="/tmp";
+  }
+  tempdir+="/rivendellXXXXXX";
+
+  //
+  // Get message part separator
+  //
+  if(getenv("REQUEST_METHOD")==NULL) {
+    return false;
+  }
+  if(QString(getenv("REQUEST_METHOD")).lower()!="post") {
+    return false;
+  }
+  if((f=fdopen(0,"r"))==NULL) {
+    return false;
+  }
+  if((n=getline(&data,(size_t *)&n,f))<=0) {
+    return false;
+  }
+  sep=QString(data).stripWhiteSpace();
+
+  //
+  // Get message parts
+  //
+  while((n=getline(&data,(size_t *)&n,f))>0) {
+    if(QString(data).stripWhiteSpace().contains(sep)>0) {  // End of part
+      if(fd>=0) {
+	ftruncate(fd,lseek(fd,0,SEEK_CUR)-2);  // Remove extraneous final CR/LF
+	::close(fd);
+	fd=-1;
+      }
+      name="";
+      filename="";
+      headers.clear();
+      header=true;
+      continue;
+    }
+    if(header) {  // Read header
+      if(QString(data).stripWhiteSpace().isEmpty()) {
+	if(!headers["content-disposition"].isNull()) {
+	  QStringList fields;
+	  fields=fields.split(";",headers["content-disposition"]);
+	  if(fields.size()>0) {
+	    if(fields[0].lower().stripWhiteSpace()=="form-data") {
+	      for(unsigned i=1;i<fields.size();i++) {
+		QStringList pairs;
+		pairs=pairs.split("=",fields[i]);
+		if(pairs[0].lower().stripWhiteSpace()=="name") {
+		  name=pairs[1].stripWhiteSpace();
+		  name.replace("\"","");
+		}
+		if(pairs[0].lower().stripWhiteSpace()=="filename") {
+		  if(tempdir.right(6)=="XXXXXX") {
+		    char dir[PATH_MAX];
+		    strcpy(dir,tempdir);
+		    mkdtemp(dir);
+		    tempdir=dir;
+		  }
+		  filename=tempdir+"/"+pairs[1].stripWhiteSpace();
+		  filename.replace("\"","");
+		  fd=open(filename,O_WRONLY|O_CREAT,S_IRUSR|S_IWUSR);
+		}
+	      }
+	    }
+	  }
+	}
+	header=false;
+      }
+      else {
+	QStringList hdr;
+	hdr=hdr.split(":",QString(data).stripWhiteSpace());
+	headers[hdr[0].lower()]=hdr[1];
+      }
+    }
+    else {  // Read data
+      if(filename.isEmpty()) {
+	(*vars)[name]+=QString(data);
+      }
+      else {
+	(*vars)[name]=filename;
+	write(fd,data,n);
+      }
+    }
+  }
+
+  free(data);
+
+  return true;
+}
+
+
+QString RDXmlField(const QString &tag,const QString &value)
+{
+  return QString("<")+tag+">"+RDXmlEscape(value)+"</"+tag+">\n";
+}
+
+
+QString RDXmlField(const QString &tag,const char *value)
+{
+  return RDXmlField(tag,QString(value));
+}
+
+
+QString RDXmlField(const QString &tag,const int value)
+{
+  return QString("<")+tag+">"+QString().sprintf("%d",value)+"</"+tag+">\n";
+}
+
+
+QString RDXmlField(const QString &tag,const unsigned value)
+{
+  return QString("<")+tag+">"+QString().sprintf("%u",value)+"</"+tag+">\n";
+}
+
+
+QString RDXmlField(const QString &tag,const bool value)
+{
+  if(value) {
+    return QString("<")+tag+">true</"+tag+">\n";
+  }
+  return QString("<")+tag+">false</"+tag+">\n";
+}
+
+
+QString RDXmlField(const QString &tag,const QDateTime &value)
+{
+  return QString("<")+tag+">"+RDWebDateTime(value)+"</"+tag+">\n";
+}
+
+
+QString RDXmlField(const QString &tag,const QTime &value)
+{
+  return QString("<")+tag+">"+value.toString("hh:mm:ss")+"</"+tag+">\n";
+}
+
+
+QString RDXmlEscape(const QString &str)
+{
+  QString ret=str;
+  ret.replace("&","&amp;");
+  ret.replace("<","&lt;");
+  ret.replace(">","&gt;");
+  ret.replace("'","&apos;");
+  ret.replace("\"","&quot;");
+  return ret;
+}
+
+
+QString RDXmlUnescape(const QString &str)
+{
+  QString ret=str;
+  ret.replace("&amp;","&");
+  ret.replace("&lt;","<");
+  ret.replace("&gt;",">");
+  ret.replace("&apos;","'");
+  ret.replace("&quot;","\"");
+  return ret;
+}
+
+
+QString RDWebDateTime(const QDateTime &datetime)
+{
+  //
+  // Generate an RFC 822/1123 compliant date/time string
+  //
+  if(!datetime.isValid()) {
+    return QString();
+  }
+  return RDLocalToUtc(datetime).toString("ddd, dd MMM yyyy hh:mm:ss")+" GMT";
+}
+
+
+QDateTime RDGetWebDateTime(const QString &str)
+{
+  QDateTime ret;
+  QStringList list;
+  QStringList dlist;
+
+  list=list.split(" ",str);
+  switch(list.size()) {
+  case 4:   // RFC 850 Style
+    dlist=dlist.split("-",list[1]);
+    if(dlist.size()==3) {
+      ret=QDateTime(QDate(dlist[2].toInt()+2000,RDGetWebMonth(dlist[1]),
+			  dlist[0].toInt()),
+		    RDGetWebTime(list[2]+" "+list[3]));
+    }
+    break;
+
+  case 5:   // ANSI C asctime() Style
+    ret=QDateTime(QDate(list[4].toInt(),RDGetWebMonth(list[1]),list[2].toInt()),
+		  RDGetWebTime(list[3]+" GMT"));
+    break;
+
+  case 6:   // RFC 822/1123 Style
+    ret=QDateTime(QDate(list[3].toInt(),RDGetWebMonth(list[2]),list[1].toInt()),
+		  RDGetWebTime(list[4]+" "+list[5]));
+    break;
+  }
+  return ret;
+}
+
+
+QTime RDGetWebTime(const QString &str)
+{
+  QTime ret;
+  QStringList list;
+
+  list=list.split(" ",str);
+  if(list.size()==2) {
+    if(list[1].lower()=="gmt") {
+      list=list.split(":",list[0]);
+      if(list.size()==3) {
+	ret=
+	  RDUtcToLocal(QTime(list[0].toInt(),list[1].toInt(),list[2].toInt()));
+      }
+    }
+  }
+
+  return ret;
+}
+
+
+int RDGetWebMonth(const QString &str)
+{
+  int ret=0;
+
+  if(str.lower()=="jan") {
+    ret=1;
+  }
+  if(str.lower()=="feb") {
+    ret=2;
+  }
+  if(str.lower()=="mar") {
+    ret=3;
+  }
+  if(str.lower()=="apr") {
+    ret=4;
+  }
+  if(str.lower()=="may") {
+    ret=5;
+  }
+  if(str.lower()=="jun") {
+    ret=6;
+  }
+  if(str.lower()=="jul") {
+    ret=7;
+  }
+  if(str.lower()=="aug") {
+    ret=8;
+  }
+  if(str.lower()=="sep") {
+    ret=9;
+  }
+  if(str.lower()=="oct") {
+    ret=10;
+  }
+  if(str.lower()=="nov") {
+    ret=11;
+  }
+  if(str.lower()=="dec") {
+    ret=12;
+  }
+
+  return ret;
+}
