@@ -2,9 +2,9 @@
 //
 // Edit an RDAirPlay Configuration
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_rdairplay.h,v 1.24.2.3 2009/03/30 19:02:52 cvs Exp $
+//      $Id: edit_rdairplay.h,v 1.29.6.1 2012/11/13 23:45:10 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -48,7 +48,7 @@ class EditRDAirPlay : public QDialog
 {
  Q_OBJECT
  public:
-  EditRDAirPlay(RDStation *station,unsigned instance,
+  EditRDAirPlay(RDStation *station,RDStation *cae_station,
 		QWidget *parent=0,const char *name=0);
   ~EditRDAirPlay();
   QSize sizeHint() const;
@@ -60,6 +60,7 @@ class EditRDAirPlay : public QDialog
   void startModeChangedData(int mode);
   void selectData();
   void nownextData();
+  void editHotKeys();
   void selectSkinData();
   void okData();
   void cancelData();
@@ -106,6 +107,7 @@ class EditRDAirPlay : public QDialog
   QSpinBox *air_audition_preroll_spin;
   QLineEdit *air_label_template_edit;
   QCheckBox *air_pause_box;
+  QCheckBox *air_hour_selector_box;
   QComboBox *air_default_transtype_box;
   QComboBox *air_defaultsvc_box;
   QLineEdit *air_exitpasswd_edit;
