@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2009 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: log_play.cpp,v 1.188.2.20 2009/08/19 12:49:36 cvs Exp $
+//      $Id: log_play.cpp,v 1.197.8.1 2012/10/09 16:42:05 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -249,9 +249,6 @@ void LogPlay::auditionHead(int line)
   if((play_audition_player==NULL)||(logline==NULL)) {
     return;
   }
-  if(logline->cartType()!=RDCart::Audio) {
-    return;
-  }
   if(play_audition_line>=0) {
     play_audition_player->stop();
   }
@@ -268,9 +265,6 @@ void LogPlay::auditionTail(int line)
   if((play_audition_player==NULL)||(logline==NULL)) {
     return;
   }
-  if(logline->cartType()!=RDCart::Audio) {
-    return;
-  }
   if(play_audition_line>=0) {
     play_audition_player->stop();
   }
@@ -362,12 +356,12 @@ bool LogPlay::stop(bool all,int port,int fade)
       }
     else {
       logline=logLine(lines[i]);
-      if(logline->cartType()==RDCart::Audio 
-            && (RDPlayDeck *)logline->playDeck()!=NULL
-            && logline->portName().toInt()==port ) {
-         stop(lines[i],fade);
-         }
+      if((logline->cartType()==RDCart::Audio)
+	 &&(RDPlayDeck *)logline->playDeck()!=NULL
+	 &&logline->portName().toInt()==port ) {
+	stop(lines[i],fade);
       }
+    }
   }
   if(n>0) {
     return true;
@@ -384,20 +378,20 @@ bool LogPlay::stop(int line,int fade)
     return false;
   }
   switch(logline->cartType()) {
-      case RDCart::Audio:
-	if(((RDPlayDeck *)logline->playDeck())==NULL) {
-	  return false;
-	}
-	((RDPlayDeck *)logline->playDeck())->stop(fade,RD_FADE_DEPTH);
-	return true;
-	break;
-
-      case RDCart::Macro:
-	play_macro_deck->stop();
-	break;
-
-      default:
-	break;
+  case RDCart::Audio:
+    if(((RDPlayDeck *)logline->playDeck())==NULL) {
+      return false;
+    }
+    ((RDPlayDeck *)logline->playDeck())->stop(fade,RD_FADE_DEPTH);
+    return true;
+    break;
+    
+  case RDCart::Macro:
+    play_macro_deck->stop();
+    break;
+    
+  case RDCart::All:
+    break;
   }
   return false;
 }
@@ -411,16 +405,17 @@ bool LogPlay::pause(int line)
     return false;
   }
   switch(logline->cartType()) {
-      case RDCart::Audio:
-	if(logline->playDeck()==NULL) {
-	  return false;
-	}
-	((RDPlayDeck *)logline->playDeck())->pause();
-	return true;
-	break;
+  case RDCart::Audio:
+    if(logline->playDeck()==NULL) {
+      return false;
+    }
+    ((RDPlayDeck *)logline->playDeck())->pause();
+    return true;
+    break;
 
-      default:
-	break;
+  case RDCart::Macro:
+  case RDCart::All:
+    break;
   }
   return false;
 }
@@ -440,12 +435,12 @@ void LogPlay::duckVolume(int level,int fade,int mport)
   int n=runningEvents(lines);
   for(int i=0;i<n;i++) {
     logline=logLine(lines[i]);
-    if(logline->cartType()==RDCart::Audio 
-          && (RDPlayDeck *)logline->playDeck()!=NULL
-          && ((logline->portName().toInt()==mport) || mport<1) ) {
-	    ((RDPlayDeck *)logline->playDeck())->duckVolume(level,fade);
-       }
+    if((logline->cartType()==RDCart::Audio) 
+       && (RDPlayDeck *)logline->playDeck()!=NULL
+       && ((logline->portName().toInt()==mport) || mport<1) ) {
+      ((RDPlayDeck *)logline->playDeck())->duckVolume(level,fade);
     }
+  }
 }
 		
 
@@ -638,13 +633,13 @@ bool LogPlay::refresh()
   if(current_id!=-1 && e->loglineById(current_id)!=NULL) {    //Make Next after currently playing cart
     if((next_line=lineById(current_id))>=0) {    
       makeNext(next_line+1,false);              
-      }
     }
+  }
   else {
     if((next_line=lineById(next_id))>=0) {     
-      makeNext(next_line,false);               
-      }
-    } 
+     makeNext(next_line,false);               
+    }
+  } 
   
   //
   // Clean Up
@@ -955,6 +950,7 @@ void LogPlay::move(int from_line,int to_line)
   else {
     UpdateStartTimes(from_line);
   }
+  SetTransTimer();
   UpdatePostPoint();
   emit inserted(to_line);
   for(int i=0;i<2;i++) {
@@ -973,7 +969,6 @@ void LogPlay::move(int from_line,int to_line)
       emit transportChanged();
     }
   }
-  SetTransTimer();
 }
 
 
@@ -1241,16 +1236,17 @@ QTime LogPlay::startTime(int line)
     return QTime();
   }
   switch(logline->cartType()) {
-      case RDCart::Audio:
-	if(((RDPlayDeck *)logline->playDeck())==NULL) {
-	  return logline->startTime(RDLogLine::Predicted);
-	}
-	return logline->startTime(RDLogLine::Actual);
-	break;
+  case RDCart::Audio:
+    if(((RDPlayDeck *)logline->playDeck())==NULL) {
+      return logline->startTime(RDLogLine::Predicted);
+    }
+    return logline->startTime(RDLogLine::Actual);
+    break;
 
-      default:
-	return logline->startTime(RDLogLine::Predicted);
-	break;
+  case RDCart::Macro:
+  case RDCart::All:
+    return logline->startTime(RDLogLine::Predicted);
+  break;
   }
   return QTime();
 }
@@ -1646,16 +1642,16 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 		  (logLine(lines[i])->type()==RDLogLine::Macro))&&
 		 (logLine(lines[i])->status()!=RDLogLine::Paused)) {
 		switch(logLine(lines[i])->cartType()) {
-		    case RDCart::Audio:
-		      ((RDPlayDeck *)logLine(lines[i])->playDeck())->stop();
-		      break;
+		case RDCart::Audio:
+		  ((RDPlayDeck *)logLine(lines[i])->playDeck())->stop();
+		  break;
+		  
+		case RDCart::Macro:
+		  play_macro_deck->stop();
+		  break;
 
-		    case RDCart::Macro:
-		      play_macro_deck->stop();
-		      break;
-
-		    default:
-		      break;
+		case RDCart::All:
+		  break;
 		}
 	      }
 	    }
@@ -1671,18 +1667,18 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 		    (prev_logline->type()==RDLogLine::Macro))&&
 		   (prev_logline->status()!=RDLogLine::Paused)) {
 		  switch(logLine(lines[i])->cartType()) {
-		      case RDCart::Audio:
-			prev_logline->setStatus(RDLogLine::Finishing);
-			((RDPlayDeck *)prev_logline->playDeck())->
-			  stop(trans_length);
-			break;
-			
-		      case RDCart::Macro:
-			play_macro_deck->stop();
-			break;
+		  case RDCart::Audio:
+		    prev_logline->setStatus(RDLogLine::Finishing);
+		    ((RDPlayDeck *)prev_logline->playDeck())->
+		      stop(trans_length);
+		    break;
 
-		      default:
-			break;
+		  case RDCart::Macro:
+		    play_macro_deck->stop();
+		    break;
+
+		  case RDCart::All:
+		    break;
 		  }
 		}
 	      }
@@ -1890,10 +1886,10 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 				   (const char *)logline->markerLabel()));
 	}
 	else {
-	 play_macro_deck->
-		load(QString().sprintf("LL %d %s -2!",
-		play_id+1,
-		(const char *)logline->markerLabel()));
+	  play_macro_deck->
+	    load(QString().sprintf("LL %d %s -2!",
+				   play_id+1,
+				   (const char *)logline->markerLabel()));
 	 /* play_macro_deck->
 	    load(QString().sprintf("LL %d %s!",
 				   play_id+1,
