@@ -2,9 +2,9 @@
 //
 // The On Air Playout Utility for Rivendell.
 //
-//   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay.cpp,v 1.171.2.9.2.1 2010/06/03 22:54:42 cvs Exp $
+//      $Id: rdairplay.cpp,v 1.189.2.2 2013/01/07 15:35:00 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -59,14 +59,19 @@
 #include <rddatedecode.h>
 #include <rddb.h>
 #include <rdescape_string.h>
+#include <dbversion.h>
 
 #include <wall_clock.h>
 #include <globals.h>
 
+#include<rdhotkeys.h>
+#include <rdhotkeylist.h>
+
 //
 // Global Resources
 //
 RDStation *rdstation_conf;
+RDSystem *rdsystem_conf;
 RDAirPlayConf *rdairplay_conf;
 RDAudioPort *rdaudioport_conf;
 RDUser *rduser;
@@ -76,6 +81,8 @@ RDEventPlayer *rdevent_player;
 RDCartDialog *rdcart_dialog;
 RDConfig *air_config;
 MainWidget *prog_ptr;
+RDHotKeyList *rdkeylist;
+RDHotkeys *rdhotkeys;
 
 //
 // Icons
@@ -107,6 +114,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   QPainter *pd=NULL;
   air_refresh_pixmap=NULL;
   air_panel=NULL;
+  bool skip_db_check=false;
+  unsigned schema=0;
 
   //
   // Ensure Single Instance
@@ -128,11 +137,6 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   connect(timer,SIGNAL(timeout()),this,SLOT(clearSplashData()));
   timer->start(AIR_PLAY_SPLASH_TIME,true);
 
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-
   //
   // Get the Startup Date/Time
   //
@@ -144,6 +148,11 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   QString lineno;
   RDCmdSwitch *cmd=new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdairplay",
 				   RDAIRPLAY_USAGE);
+  for(unsigned i=0;i<cmd->keys();i++) {
+    if(cmd->key(i)=="--skip-db-check") {
+      skip_db_check=true;
+    }
+  }
   for(unsigned i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
     air_start_line[i]=0;
     air_start_start[i]=false;
@@ -190,6 +199,11 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   qApp->setFont(default_font);
   QFont button_font=QFont("Helvetica",16,QFont::Bold);
   button_font.setPixelSize(16);
+  for(unsigned i=0;i<AIR_MESSAGE_FONT_QUANTITY;i++) {
+    air_message_fonts[i]=QFont("helvetica",12+2*i,QFont::Normal);
+    air_message_fonts[i].setPixelSize(12+2*i);
+    air_message_metrics[i]=new QFontMetrics(air_message_fonts[i]);
+  }
 
   //
   // Create And Set Icon
@@ -215,7 +229,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   air_config->load();
   logfile=air_config->airplayLogname();
 
-  str=QString(tr("RDAirPlay - Host:"));
+  str=QString("RDAirPlay")+" v"+VERSION+" - "+tr("Host:");
   setCaption(QString().sprintf("%s %s",(const char *)str,
 			       (const char *)air_config->stationName()));
 
@@ -223,13 +237,18 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Open Database
   //
   QString err;
-  QSqlDatabase *db = RDInitDb (&err);
+  QSqlDatabase *db=RDInitDb(&schema,&err);
   if(!db) {
     QMessageBox::warning(this,tr("Database Error"),
 			 //tr("Can't Connect","Unable to connect to mySQL Server!"));
 			 err);
     exit(0);
   }
+  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
+    fprintf(stderr,"rdlogin: database version mismatch, should be %u, is %u\n",
+	    RD_VERSION_DATABASE,schema);
+    exit(256);
+  }
   connect (RDDbStatus(),SIGNAL(logText(RDConfig::LogPriority,const QString &)),
 	   this,SLOT(logLine(RDConfig::LogPriority,const QString &))); 
 
@@ -240,16 +259,11 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   connect(air_master_timer,SIGNAL(timeout()),this,SLOT(masterTimerData()));
   air_master_timer->start(MASTER_TIMER_INTERVAL);
 
-  //
-  // CAE Connection
-  //
-  rdcae=new RDCae(parent,name);
-  rdcae->connectHost("localhost",CAED_TCP_PORT,air_config->password());
-
   //
   // Allocate Global Resources
   //
   rdstation_conf=new RDStation(air_config->stationName());
+  rdsystem_conf=new RDSystem();
   rdairplay_conf=new RDAirPlayConf(air_config->stationName(),0);
   rdairplay_previous_exit_code=rdairplay_conf->exitCode();
   rdairplay_conf->setExitCode(RDAirPlayConf::ExitDirty);
@@ -265,6 +279,12 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
     setErasePixmap(*mainmap);
   }
 
+  //
+  // CAE Connection
+  //
+  rdcae=new RDCae(rdstation_conf,air_config,parent,name);
+  rdcae->connectHost();
+
   //
   // Set Audio Assignments
   //
@@ -359,8 +379,9 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Cart Picker
   //
   rdcart_dialog=new RDCartDialog(&air_add_filter,&air_add_group,
+				 &air_add_schedcode,
 				 air_cue_card,air_cue_port,0,0,
-				 rdcae,rdripc,rdstation_conf,
+				 rdcae,rdripc,rdstation_conf,rdsystem_conf,
 				 rdstation_conf->editorPath(),
 				 this,"rdcart_dialog");
 
@@ -796,6 +817,14 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   }
   delete q;
 
+  // Create the HotKeyList object
+  //
+  rdkeylist = new RDHotKeyList();
+  rdhotkeys = new RDHotkeys(RDEscapeString(air_config->stationName()),
+		  "airplay");
+  AltKeyHit = false;
+  CtrlKeyHit = false;
+
   //
   // Set Signal Handlers
   //
@@ -1560,15 +1589,30 @@ void MainWidget::keyPressEvent(QKeyEvent *e)
 	}
 	break;
 
+      case Qt::Key_Alt:
+        keystrokecount++;
+        AltKeyHit = true;
+        break;
+
+      case Qt::Key_Control:
+        keystrokecount++;
+        CtrlKeyHit = true;
+        break;
+
       default:
-	e->ignore();
+        QWidget::keyPressEvent(e);
 	break;
   }
 }
 
-
 void MainWidget::keyReleaseEvent(QKeyEvent *e)
 {
+  int keyhit = e->key();
+  QString mystring=(*rdkeylist).GetKeyCode(keyhit);
+  QString hotkeystrokes;
+  QString hot_label;
+  QString temp_string;
+
   switch(e->key()) {
       case Qt::Key_Space:
 	switch(air_bar_action) {
@@ -1583,14 +1627,135 @@ void MainWidget::keyReleaseEvent(QKeyEvent *e)
 	      break;
 	}
 	break;
+  }
+//  Try to figure out if this is a hot key combination
+  if ( (e->key() == Qt::Key_Shift) || 
+       (e->key() == Qt::Key_Up) || 
+       (e->key() == Qt::Key_Left) ||
+       (e->key() == Qt::Key_Right) ||
+       (e->key() == Qt::Key_Down) )    {
+      QWidget::keyReleaseEvent(e);
+      keystrokecount = 0;
+      hotkeystrokes = QString ("");
+      return;
+  }
 
-      default:
-	QWidget::keyReleaseEvent(e);
-	break;
- }
+  if ((e->key() == Qt::Key_Alt) ||
+      (e->key() == Qt::Key_Control)) {
+      if (keystrokecount != 0 ) hotkeystrokes = QString ("");
+      if (AltKeyHit) {
+          AltKeyHit = false;
+          if (keystrokecount > 0) keystrokecount--;
+      }
+      if (CtrlKeyHit) {
+          CtrlKeyHit = false;
+          if (keystrokecount > 0) keystrokecount--;
+      }
+      return;
+  }
+
+  if (!e->isAutoRepeat()) {
+      if (keystrokecount == 0)
+          hotkeystrokes = QString ("");
+      if (AltKeyHit) {
+          hotkeystrokes =  (*rdkeylist).GetKeyCode(Qt::Key_Alt);
+          hotkeystrokes +=  QString(" + ");
+      }
+      if (CtrlKeyHit) {
+          if (AltKeyHit) {
+              hotkeystrokes +=  (*rdkeylist).GetKeyCode(Qt::Key_Control);
+              hotkeystrokes += QString (" + ");
+          }
+          else {
+              hotkeystrokes =  (*rdkeylist).GetKeyCode(Qt::Key_Control);
+              hotkeystrokes += QString (" + ");
+          }
+      }
+
+      hotkeystrokes += mystring; 
+      keystrokecount = 0 ;
+  }
+  
+      // Have any Hot Key Combinations now...
+
+  if (hotkeystrokes.length() > 0)  {
+
+    hot_label=(*rdhotkeys).GetRowLabel(RDEscapeString(air_config->stationName()),
+                        (const char *)"airplay",(const char *)hotkeystrokes);
+
+    if (hot_label.length()>0) {
+
+        // "we found a keystroke label
+ 
+        if (strcmp(hot_label,"Add") == 0)
+        {
+            addButtonData();
+            return;
+        }
+
+        if (strcmp(hot_label,"Delete") == 0)
+        {
+            deleteButtonData();
+            return;
+        }
+
+        if (strcmp(hot_label,"Copy") == 0)
+        {
+            copyButtonData();
+            return;
+        }
+
+        if (strcmp(hot_label,"Move") == 0)
+        {
+            moveButtonData();
+            return;
+        }
+    
+        if (strcmp(hot_label,"Sound Panel") == 0)
+        {
+            panelButtonData();
+            return;
+        }
+    
+        if (strcmp(hot_label,"Main Log") == 0)
+        {
+            fullLogButtonData(0);
+            return;
+        }
+    
+        if ((strcmp(hot_label,"Aux Log 1") == 0) &&
+             (rdairplay_conf->showAuxButton(0) ) )
+        {
+            fullLogButtonData(1);
+            return;
+        }
+    
+        if ( (strcmp(hot_label,"Aux Log 2") == 0) &&
+             (rdairplay_conf->showAuxButton(1) ) )
+        {
+            fullLogButtonData(2);
+            return;
+        }
+    
+        for (int i = 1; i < 8 ; i++)
+        {
+            temp_string = QString().sprintf("Start Line %d",i);
+            if (strcmp(hot_label,temp_string) == 0)
+                air_button_list->startButton(i-1);
+    
+            temp_string = QString().sprintf("Stop Line %d",i);
+            if (strcmp(hot_label,temp_string) == 0)
+                air_button_list->stopButtonHotkey(i-1);
+    
+            temp_string = QString().sprintf("Pause Line %d",i);
+            if (strcmp(hot_label,temp_string) == 0)
+                air_button_list->pauseButtonHotkey(i-1);
+        }
+      }
+  }
+  QWidget::keyReleaseEvent(e);
 }
 
-
 void MainWidget::closeEvent(QCloseEvent *e)
 {
   if(!rdairplay_conf->exitPasswordValid("")) {
@@ -1655,12 +1820,11 @@ void MainWidget::SetCaption()
   if(log.isEmpty()) {
     log="--    ";
   }
-  setCaption(QString().
-	     sprintf("RDAirPlay - Host: %s  User: %s  Log: %s  Service: %s",
-		     (const char *)air_config->stationName(),
-		     (const char *)rdripc->user(),
-		     (const char *)log.left(log.length()-4),
-		     (const char *)air_log[0]->serviceName()));
+  setCaption(QString("RDAirPlay")+" v"+VERSION+" - "+tr("Host")+": "+
+	     air_config->stationName()+" "+
+	     tr("User:")+" "+rdripc->user()+" "+
+	     tr("Log:")+" "+log.left(log.length()-4)+" "+
+	     tr("Service:")+" "+air_log[0]->serviceName());
 }
 
 
@@ -1796,12 +1960,6 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
           }
 
 	}
-	/*
-	dialog=new RDCartDialog(&air_add_cart,&air_add_filter,&air_add_group,
-				RDCart::All,svc_name,svc_quan,air_cue_card,
-				air_cue_port,0,0,rdcae,rdripc,rdstation_conf,
-				air_editor_cmd,this,"cart_add_dialog");
-	*/
 	air_add_button->setFlashColor(BUTTON_FROM_BACKGROUND_COLOR);
 	air_add_button->setFlashingEnabled(true);
 	air_delete_button->setFlashingEnabled(false);
@@ -1814,7 +1972,8 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	if(air_panel!=NULL) {
 	  air_panel->setActionMode(RDAirPlayConf::Normal);
 	}
-	if(rdcart_dialog->exec(&air_add_cart,RDCart::All,0,0)==0) {
+	if(rdcart_dialog->exec(&air_add_cart,RDCart::All,0,0,
+			       rduser->name(),rduser->password())==0) {
 	  SetActionMode(StartButton::AddTo);
 	}
 	else {
