@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_upload.h,v 1.8 2007-12-31 18:49:10 fredg Exp $
+//      $Id: edit_upload.h,v 1.12 2010/07/29 19:32:36 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -88,6 +88,7 @@ class EditUpload : public QDialog
   QLabel *edit_normalize_label;
   QSpinBox *edit_normalize_spin;
   QLabel *edit_normalize_unit;
+  QCheckBox *edit_metadata_box;
   QCheckBox *edit_sun_button;
   QCheckBox *edit_mon_button;
   QCheckBox *edit_tue_button;
@@ -95,6 +96,7 @@ class EditUpload : public QDialog
   QCheckBox *edit_thu_button;
   QCheckBox *edit_fri_button;
   QCheckBox *edit_sat_button;
+  QSpinBox *edit_eventoffset_spin;
   QCheckBox *edit_oneshot_box;
   std::vector<int> *edit_added_events;
   QString *edit_filter;
