@@ -384,6 +384,10 @@ for the selected service!</source>
         <source>Select</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Unable to save log, audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -684,14 +688,6 @@ group for the specified service!</source>
 </context>
 <context>
     <name>MainWidget</name>
-    <message>
-        <source>RDLogEdit - Host</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>User: [Unknown]</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Can&apos;t Connect</source>
         <translation type="unfinished"></translation>
@@ -811,5 +807,242 @@ Continue?</source>
         <source>TFN</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLogEdit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete log, audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLogEdit -- Database Skew</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This version of RDLogEdit is incompatible with the version installed on the server.
+See your system administrator for an update!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>VoiceTracker</name>
+    <message>
+        <source>Voice Tracker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Cue Markers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Undo Segue Changes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Start Point Here</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set End Point Here</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set to Hook Markers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Previous
+Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Next
+Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remaining</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TIME</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TRANS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CART</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>GROUP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LENGTH</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TITLE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ARTIST</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do Over</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hit Post</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Insert
+Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete
+Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No VoiceTrack Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No voicetracking group has been defined for this service,
+therefore only existing transitions will be editable.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart Creation Failure</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create new cart for voice track!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLogEdit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio Deletion Error!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TRACK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Voice Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No more tracks!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[end of log]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[cart not found]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MARKER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LOG CHAIN</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LINK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[music import]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[traffic import]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PLAY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SEGUE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Segue Changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save segue changes?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
