@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_events.cpp,v 1.26 2007/09/14 14:06:58 fredg Exp $
+//      $Id: list_events.cpp,v 1.31.8.1 2012/04/23 17:22:47 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,8 +27,8 @@
 #include <qtextedit.h>
 #include <qpainter.h>
 #include <qmessagebox.h>
-#include <qsqldatabase.h>
 
+#include <rddb.h>
 #include <rd.h>
 #include <rdevent.h>
 #include <rdcreate_log.h>
@@ -43,8 +43,11 @@
 ListEvents::ListEvents(QString *eventname,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
+  QStringList services_list;
+  QString str1=tr("Log Events - User: ");
+  setCaption(QString().sprintf("%s%s",(const char *)str1,
+			       (const char *)rdripc->user()));
   edit_eventname=eventname;
-  setCaption(tr("Log Events"));
 
   //
   // Fix the Window Size
@@ -167,13 +170,27 @@ ListEvents::ListEvents(QString *eventname,QWidget *parent,const char *name)
   //
   edit_filter_box->insertItem(tr("ALL"));
   edit_filter_box->insertItem(tr("NONE"));
-  QSqlQuery *q=new QSqlQuery("select NAME from SERVICES order by NAME");
-  while(q->next()) {
-    edit_filter_box->insertItem(q->value(0).toString());
-    if(*event_filter==q->value(0).toString()) {
+
+  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+    services_list = rduser->services();
+  } else { // RDStation::HostSec
+    QString sql="select NAME from SERVICES";
+    RDSqlQuery *q=new RDSqlQuery(sql);
+    while(q->next()) {
+      services_list.append( q->value(0).toString() );
+    }
+    delete q;
+  } 
+  services_list.sort();
+  for ( QStringList::Iterator it = services_list.begin(); 
+        it != services_list.end();
+        ++it ) {
+    edit_filter_box->insertItem(*it);
+    if(*event_filter==*it) {
       edit_filter_box->setCurrentItem(edit_filter_box->count()-1);
     }
   }
+
   RefreshList();
 }
 
@@ -194,8 +211,8 @@ void ListEvents::addData()
 {
   QString logname;
   RDEvent *event;
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
   std::vector<QString> new_events;
 
   AddEvent *add_dialog=new AddEvent(&logname,this,"add_dialog");
@@ -206,7 +223,7 @@ void ListEvents::addData()
   delete add_dialog;
   QString sql=QString().sprintf("select NAME from EVENTS where NAME=\"%s\"",
 				(const char *)logname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     QMessageBox::
       information(this,tr("Event Exists"),
@@ -222,20 +239,20 @@ void ListEvents::addData()
   if(event_dialog->exec()<-1) {
     sql=QString().sprintf("delete from EVENTS where NAME=\"%s\"",
 			  (const char *)logname);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
     return;
   }
   else {
     if(edit_filter_box->currentItem()==0) {
       sql="select NAME from SERVICES";
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
       while(q->next()) {
 	sql=QString().sprintf("insert into EVENT_PERMS set\
                                EVENT_NAME=\"%s\",SERVICE_NAME=\"%s\"",
 			      (const char *)logname,
 			      (const char *)q->value(0).toString());
-	q1=new QSqlQuery(sql);
+	q1=new RDSqlQuery(sql);
 	delete q1;
       }
       delete q;
@@ -245,7 +262,7 @@ void ListEvents::addData()
                              EVENT_NAME=\"%s\",SERVICE_NAME=\"%s\"",
 			    (const char *)logname,
 			    (const char *)edit_filter_box->currentText());
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
       delete q;
     }
   }
@@ -319,8 +336,8 @@ void ListEvents::deleteData()
 void ListEvents::renameData()
 {
   QString sql;
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
   QString clock_name_esc;
   QListViewItem *item=edit_events_list->selectedItem();
   if(item==NULL) {
@@ -339,7 +356,7 @@ void ListEvents::renameData()
   // Rename Clock References
   //
   sql="select NAME from CLOCKS";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     clock_name_esc=q->value(0).toString();
     clock_name_esc.replace(" ","_");
@@ -348,7 +365,7 @@ void ListEvents::renameData()
 			  (const char *)clock_name_esc,
 			  (const char *)new_name,
 			  (const char *)item->text(0));
-    q1=new QSqlQuery(sql);
+    q1=new RDSqlQuery(sql);
     delete q1;
   }
   delete q;
@@ -363,12 +380,12 @@ void ListEvents::renameData()
   sql=QString().sprintf("alter table %s_PRE rename to %s_PRE",
 			(const char *)old_name_esc,
 			(const char *)new_name_esc);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("alter table %s_POST rename to %s_POST",
 			(const char *)old_name_esc,
 			(const char *)new_name_esc);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
@@ -378,7 +395,7 @@ void ListEvents::renameData()
                          where EVENT_NAME=\"%s\"",
 			(const char *)new_name,
 			(const char *)item->text(0));
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
@@ -387,7 +404,7 @@ void ListEvents::renameData()
   sql=QString().sprintf("update EVENTS set NAME=\"%s\" where NAME=\"%s\"",
 			(const char *)new_name,
 			(const char *)item->text(0));
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   item->setText(0,new_name);
@@ -437,6 +454,12 @@ void ListEvents::cancelData()
 }
 
 
+void ListEvents::closeEvent(QCloseEvent *e)
+{
+  cancelData();
+}
+
+
 void ListEvents::RefreshList()
 {
   QString filter;
@@ -453,7 +476,7 @@ void ListEvents::RefreshList()
   edit_events_list->clear();
   QString sql=QString().sprintf("select NAME,PROPERTIES,COLOR from EVENTS %s",
 				(const char *)filter);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   QListViewItem *item=NULL;
   while(q->next()) {
     item=new QListViewItem(edit_events_list);
@@ -484,7 +507,7 @@ void ListEvents::UpdateItem(QListViewItem *item,QString name)
 {
   QString sql=QString().sprintf("select NAME,PROPERTIES,COLOR from EVENTS\
                                  where NAME=\"%s\"",(const char *)name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->next()) {
     item->setText(0,name);
     WriteItem(item,q);
@@ -493,7 +516,7 @@ void ListEvents::UpdateItem(QListViewItem *item,QString name)
 }
 
 
-void ListEvents::WriteItem(QListViewItem *item,QSqlQuery *q)
+void ListEvents::WriteItem(QListViewItem *item,RDSqlQuery *q)
 {
   QPixmap *pix;
   QPainter *p=new QPainter();
@@ -514,18 +537,18 @@ int ListEvents::ActiveEvents(QString event_name,QString *clock_list)
 {
   int n=0;
   QString sql;
-  QSqlQuery *q,*q1;
+  RDSqlQuery *q,*q1;
   QString clockname;
 
   sql="select NAME from CLOCKS";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     clockname=q->value(0).toString();
     clockname.replace(" ","_");
     sql=QString().sprintf("select EVENT_NAME from %s_CLK\
                            where EVENT_NAME=\"%s\"",(const char *)clockname,
 			  (const char *)event_name);
-    q1=new QSqlQuery(sql);
+    q1=new RDSqlQuery(sql);
     if(q1->first()) {
       *clock_list+=
 	QString().sprintf("    %s\n",(const char *)q->value(0).toString());
@@ -541,7 +564,7 @@ int ListEvents::ActiveEvents(QString event_name,QString *clock_list)
 void ListEvents::DeleteEvent(QString event_name)
 {
   QString sql;
-  QSqlQuery *q,*q1;
+  RDSqlQuery *q,*q1;
   QString clockname;
   QString base_name=event_name;
   base_name.replace(" ","_");
@@ -550,14 +573,14 @@ void ListEvents::DeleteEvent(QString event_name)
   // Delete Active Clock Entries
   //
   sql="select NAME from CLOCKS";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     clockname=q->value(0).toString();
     clockname.replace(" ","_");
     sql=QString().sprintf("delete from %s_CLK\
                            where EVENT_NAME=\"%s\"",(const char *)clockname,
 			  (const char *)event_name);
-    q1=new QSqlQuery(sql);
+    q1=new RDSqlQuery(sql);
     delete q1;
   }
   delete q;
@@ -567,7 +590,7 @@ void ListEvents::DeleteEvent(QString event_name)
   //
   sql=QString().sprintf("delete from EVENT_PERMS where EVENT_NAME=\"%s\"",
 			(const char *)event_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
@@ -575,13 +598,13 @@ void ListEvents::DeleteEvent(QString event_name)
   //
   sql=QString().sprintf("delete from EVENTS where NAME=\"%s\"",
 			(const char *)event_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("drop table %s_PRE",(const char *)base_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("drop table %s_POST",(const char *)base_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
 }
 
 
@@ -591,7 +614,7 @@ QString ListEvents::GetEventFilter(QString svc_name)
   QString sql=QString().sprintf("select EVENT_NAME from EVENT_PERMS\
                                  where SERVICE_NAME=\"%s\"",
 				(const char *)svc_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->size()>0) {
     while(q->next()) {
       filter+=QString().sprintf("(NAME=\"%s\")||",
@@ -611,11 +634,11 @@ QString ListEvents::GetEventFilter(QString svc_name)
 QString ListEvents::GetNoneFilter()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString filter;
 
   sql="select EVENT_NAME from EVENT_PERMS";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->size()>0) {
     filter="where ";
   }
