@@ -499,6 +499,18 @@ Do you want to overwrite it?</source>
         <source>REMARKS</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Len:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PRE-IMPORT CARTS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IMPORT</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -566,6 +578,10 @@ already existing event.</source>
         <source>&amp;Close</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clear Hour</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -660,6 +676,18 @@ already existing event.</source>
 Do you want to save?</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scheduler Rules</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist Separation:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import Rules from Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTrack</name>
@@ -1126,6 +1154,15 @@ Data</source>
         <source>RDLogManager - User: </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLogEdit -- Database Skew</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This version of RDLogManager is incompatible with the version installed on the server.
+See your system administrator for an update!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PickReportDates</name>
@@ -1179,7 +1216,7 @@ Report</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Report complete!</source>
+        <source>Report generated in</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1291,5 +1328,9 @@ Data</source>
         <source>Or after:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Rules for Code</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
