@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: btss42.cpp,v 1.7 2008/10/01 13:10:15 fredg Exp $
+//      $Id: btss42.cpp,v 1.12 2010/08/03 23:39:26 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,7 @@
 
 
 BtSs42::BtSs42(RDMatrix *matrix,QObject *parent,const char *name)
-  : QObject(parent,name)
+  : Switcher(matrix,parent,name)
 {
   //
   // Initialize Data Structures
@@ -90,13 +90,42 @@ BtSs42::~BtSs42()
 }
 
 
+RDMatrix::Type BtSs42::type()
+{
+  return RDMatrix::BtSs42;
+}
+
+
+unsigned BtSs42::gpiQuantity()
+{
+  return bt_gpis;
+}
+
+
+unsigned BtSs42::gpoQuantity()
+{
+  return bt_gpos;
+}
+
+
+bool BtSs42::primaryTtyActive()
+{
+  return true;
+}
+
+
+bool BtSs42::secondaryTtyActive()
+{
+  return false;
+}
+
+
 void BtSs42::processCommand(RDMacro *cmd)
 {
   char str[9];
 
   switch(cmd->command()) {
       case RDMacro::GO:
-// NEW
 	if((cmd->argQuantity()!=5)||
 	   ((cmd->arg(1).toString().lower()!="i")&&
 	    (cmd->arg(1).toString().lower()!="o"))||
