@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: loaddrivers.cpp,v 1.1.8.1 2012/08/06 00:12:07 cvs Exp $
+//      $Id: loaddrivers.cpp,v 1.1.8.2 2012/12/11 03:49:48 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -49,6 +49,7 @@
 #include <btsrc8iii.h>
 #include <btsrc16.h>
 #include <harlond.h>
+#include <acu1p.h>
 
 bool MainObject::LoadSwitchDriver(int matrix_num)
 {
@@ -151,6 +152,10 @@ bool MainObject::LoadSwitchDriver(int matrix_num)
     ripcd_switcher[matrix_num]=new Harlond(matrix,this);
     break;
 
+  case RDMatrix::Acu1p:
+    ripcd_switcher[matrix_num]=new Acu1p(matrix,this);
+    break;
+
   default:
     ripcd_switcher[matrix_num]=NULL;
     delete matrix;
